# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnGeolibServices.ExpressionMath as ExpressionMath
import PyFnGeolib as FnGeolib
import UI4.Widgets.LightingToolsLayer.LightingToolsUtils as LightingToolsUtils
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import PyFnAttribute
import PyFnGeolib
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import UI4.FormMaster.KatanaFactory
import Utils as Utils
import ViewerAPI
import typing
from Callbacks.Callbacks import Callbacks as Callbacks
from UI4.Widgets.HBoxLayoutResizer import HBoxLayoutResizer
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

global_leakyWidgetFactory: LeakyWidgetFactory
kFileWidgetTypes: set
kSupportedWidgetTypes: set

class BaseColumn(PyQt5.QtWidgets.QWidget):
    kBorderRadius: ClassVar[float] = ...
    kFixedHeight: ClassVar[int] = ...
    kMinimumWidth: ClassVar[int] = ...
    def __init__(self, orientation: PyQt5.QtCore.Qt.Orientation = ..., parent: Incomplete | None = ...) -> None: ...
    def _addSpacer(self, count: int = ...): ...
    def mousePressEvent(self, event: PyQt5.QtGui.QMouseEvent): ...

class DragArea(HoverableButton):
    kPad: ClassVar[int] = ...
    def __init__(self, uiWidget: PyQt5.QtWidgets.QWidget, parent: Incomplete | None = ...) -> None: ...
    def getLastDragPosition(self) -> PyQt5.QtCore.QPointF: ...
    def mouseMoveEvent(self, mouseEvent): ...
    def mousePressEvent(self, mouseEvent): ...
    def mouseReleaseEvent(self, mouseEvent): ...

class DragAreaColumn(BaseColumn):
    toggled: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def getHandleRect(self) -> PyQt5.QtCore.QRect: ...
    def getLastDragPosition(self) -> PyQt5.QtCore.QPointF: ...
    def isChecked(self) -> DragArea: ...
    def setRowSpan(self, span: int, padding: int = ...): ...

class HoverableButton(PyQt5.QtWidgets.QPushButton):
    def __init__(self, normalPath: str, activePath: str, parent: Incomplete | None = ...) -> None: ...
    def _HoverableButton__update(self): ...
    def enterEvent(self, event): ...
    def leaveEvent(self, event): ...
    def mouseMoveEvent(self, event): ...
    def setChecked(self, checked): ...

class LabelsColumn(BaseColumn):
    def __init__(self, labels: list[str], widgetTypes: list[str], parameterPathLists, parent: Incomplete | None = ...) -> None: ...
    def _LabelsColumn__buildLabel(self, text: str, toolTip: str) -> PyQt5.QtWidgets.QLabel: ...
    def _LabelsColumn__buildToolTip(self, widgetType: str, parameterPaths: list[str]) -> str: ...
    def mousePressEvent(self, event: PyQt5.QtGui.QMouseEvent): ...

class LeakyWidgetFactory(UI4.FormMaster.KatanaFactory.ParameterWidgetFactoryClass):
    def getWidgetClass(self, policy: UI4.QT4FormWidgets.AbstractValuePolicy, hints: dict) -> type: ...

class LightingToolsUI(PyQt5.QtWidgets.QWidget):
    kDefaultPosition: ClassVar[tuple] = ...
    starredLocationsChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, viewerDelegate: ViewerAPI.ViewerDelegate, viewportWidget: ViewerAPI.ViewportWidget, parent: Incomplete | None = ...) -> None: ...
    def _LightingToolsUI__addParameterGroup(self, location: str): ...
    def _LightingToolsUI__adjustScrollerHeight(self): ...
    def _LightingToolsUI__getAttributes(self, location: str, client: PyFnGeolib.GeolibRuntime.Client | None, pendinglocationEvents: list[None], fallbackFn: Incomplete | None = ...) -> PyFnAttribute.GroupAttribute | None: ...
    def _LightingToolsUI__onLocationStarChanged(self, location: str, starred: bool): ...
    def _LightingToolsUI__onSceneAboutToLoad(self): ...
    def _LightingToolsUI__on_dragArea_toggled(self, checked: bool): ...
    def _LightingToolsUI__on_nodeLocked(self): ...
    def _LightingToolsUI__on_nodegraphChanged(self): ...
    def _LightingToolsUI__on_scenegraphLocationRenamed(self): ...
    def _LightingToolsUI__rebuildUI(self): ...
    def _LightingToolsUI__removeParameterGroup(self, location: str): ...
    def cleanup(self): ...
    def clear(self): ...
    def eventFilter(self, recipient, event): ...
    def getGafferAttributes(self, location: str) -> PyFnAttribute.GroupAttribute | None: ...
    def getViewAttributes(self, location: str) -> PyFnAttribute.GroupAttribute | None: ...
    def getVisibleLocations(self) -> set[str]: ...
    def paintEvent(self, event): ...
    def processLocationEvents(self): ...
    def rebuildUI(self): ...
    def setFocused(self, locations: typing.Iterable[str]): ...
    def setSelectedGafferNodeName(self, gafferName: str): ...
    def setSelectedLocations(self, locations): ...
    def updateGafferClient(self, gafferNodeName: str): ...
    def updateViewClient(self, viewerDelegate: ViewerAPI.ViewerDelegate, viewOp: GeolibRuntimeOp | None): ...
    def wheelEvent(self, event): ...

class ParameterColumn(BaseColumn):
    iconToggled: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    starChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, location: str, lightingToolsUI: LightingToolsUI, parent: Incomplete | None = ...) -> None: ...
    def _ParameterColumn__createLightIcon(self) -> PyQt5.QtWidgets.QWidget: ...
    def _ParameterColumn__createLocationLabel(self) -> PyQt5.QtWidgets.QLabel: ...
    def _ParameterColumn__createMissingWidget(self) -> PyQt5.QtWidgets.QLabel: ...
    def _ParameterColumn__createMuteAndSoloToolBar(self) -> PyQt5.QtWidgets.QToolBar: ...
    def _ParameterColumn__createPolicyWidget(self, policy: UI4.QT4FormWidgets.AbstractValuePolicy) -> QT4FormWidgets.FormWidget: ...
    def _ParameterColumn__createStarButton(self) -> PyQt5.QtWidgets.QPushButton: ...
    def _ParameterColumn__getLabelText(self) -> str: ...
    def _ParameterColumn__rebuildWidgets(self): ...
    def _ParameterColumn__styleWidget(self, widget: PyQt5.QtWidgets.QWidget): ...
    def getGafferNodeName(self) -> str: ...
    def getLocationLabel(self) -> RotatedLabel: ...
    def getLocationPath(self) -> str: ...
    def getParameterKeys(self): ...
    def getParameterOrdering(self) -> list[str]: ...
    def getParameterPaths(self) -> list[str]: ...
    def isParametersHashValid(self) -> bool: ...
    def mousePressEvent(self, event): ...
    def mouseReleaseEvent(self, event): ...
    def paintEvent(self, event: PyQt5.QtGui.QPaintEvent): ...
    def refreshState(self, attrs: Incomplete | None = ...): ...
    def setEnabled(self, enabled: bool): ...
    def setGafferNodeName(self, gafferName: str): ...
    def setIconChecked(self, checked: bool): ...
    def setIconEdges(self, edges: PyQt5.QtCore.Qt.Edge): ...
    def setLabelAdornment(self, adornment: Tuple[float, str | None]): ...
    def setOverrideIconName(self, iconName: str): ...
    def setParameterOrdering(self, ordering: list[str]): ...
    def setStarred(self, starred: bool): ...

class ParameterColumnGroup(BaseColumn):
    starChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, location: str, lightingToolsUI: LightingToolsUI, parent: Incomplete | None = ...) -> None: ...
    def _ParameterColumnGroup__buildRelatedColumns(self) -> list[ParameterColumn]: ...
    def _ParameterColumnGroup__createColumn(self, location: str) -> ParameterColumn: ...
    def _ParameterColumnGroup__getPrincipalColumn(self) -> ParameterColumn: ...
    def _ParameterColumnGroup__getRelatedLightPaths(self) -> list | str: ...
    def _ParameterColumnGroup__onSelectedLocationColumnToggled(self, *_args): ...
    def _ParameterColumnGroup__onTemplateMaterialColumnToggled(self, *_args): ...
    def _ParameterColumnGroup__updateColumnVisibility(self): ...
    def _ParameterColumnGroup__updateLayout(self): ...
    def _ParameterColumnGroup__updateTemplateMaterialCount(self): ...
    def _ParameterColumnGroup__updateWidth(self): ...
    def getColumns(self) -> typing.Iterator[ParameterColumn]: ...
    def getExpandedState(self) -> None: ...
    def getGafferNodeName(self) -> str: ...
    def getNumberOfVisibleColumns(self): ...
    def getParameterKeys(self): ...
    def getParameterPaths(self) -> list[str]: ...
    def getTemplateMaterialPath(self) -> str | None: ...
    def isParametersHashValid(self) -> bool: ...
    def mousePressEvent(self, event): ...
    def refreshRelatedLocations(self): ...
    def refreshState(self, attrsDict: Incomplete | None = ...): ...
    def setExpandedState(self, templateMaterialVisible: bool, relatedVisible: bool): ...
    def setGafferNodeName(self, gafferName: str): ...
    def setParameterOrdering(self, ordering: list[str]): ...
    def setStarred(self, starredLocations: set[str]): ...
    def setTemplateMaterialPath(self, templateMaterialPath: str | None): ...

class ParameterResizer(HBoxLayoutResizer):
    kMaximumWidth: ClassVar[int] = ...
    kMinimumWidth: ClassVar[int] = ...
    def __init__(self, targetWidget) -> None: ...
    def hasBeenManuallyResized(self) -> bool: ...
    def mouseDoubleClickEvent(self, event): ...
    def mouseMoveEvent(self, event): ...

class RotatedLabel(PyQt5.QtWidgets.QLabel):
    def __init__(self, text: str, angle: float) -> None: ...
    def _RotatedLabel__getBoxSize(self, fontMetrics: PyQt5.QtGui.QFontMetrics) -> None: ...
    def draw(self, paintDevice: PyQt5.QtGui.QPaintDevice): ...
    def paintEvent(self, event: PyQt5.QtGui.QPaintEvent): ...
    def setFocused(self, focused: bool): ...
    def setHighlighted(self, highlighted: bool): ...
    def sizeHint(self) -> PyQt5.QtCore.QSize: ...

class RoundedCap(PyQt5.QtWidgets.QFrame):
    def __init__(self, edge: PyQt5.QtCore.Qt.Edge, parent: Incomplete | None = ...) -> None: ...

class RoundedCapsColumn(BaseColumn):
    def __init__(self, edge: PyQt5.QtCore.Qt.Edge, numRows: int, parent: Incomplete | None = ...) -> None: ...

def ClearLayout(layout: PyQt5.QtWidgets.QLayout): ...
def ConvertParameterPathToTitleCaseLabel(text: str) -> str: ...
def DefineParameterWidgetType(policy: QT4FormWidgets.AbstractValuePolicy) -> QT4FormWidgets.FormWidget: ...
def GetAllLightPaths(worldAttrs: PyFnAttribute.GroupAttribute) -> list | str: ...
def GetWidgetType(policy: QT4FormWidgets.AbstractValuePolicy) -> str | None: ...
def IsSupportedWidgetType(widgetType: str | None) -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyOpenColorIO as OCIO
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from PyUtilModule.VirtualKatana import Widgets as Widgets
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from typing import Set, Tuple

class HistogramPanel(BaseTab):
    def __init__(self, parent) -> None: ...
    def _HistogramPanel__channelsChanged_CB(self, ev): ...
    def _HistogramPanel__colorspaceChanged_CB(self, ev): ...
    def _HistogramPanel__monitor_pixelProbeResult_CB(self, eventType, eventID, **kwargs): ...
    def _HistogramPanel__scaleChanged_CB(self, ev): ...
    def _HistogramPanel__setTraceLocation_CB(self, x): ...
    def _HistogramPanel__showTrace_CB(self, showTrace): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel as SortablePanel
import UI4 as UI4
import UI4.Widgets.SortablePanel
import Naming as UniqueName
import typing
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class AssetWidgetHintsDialog(DefaultWidgetHintsDialog):
    TRUEFALSEHINTS: ClassVar[dict] = ...
    def _AssetWidgetHintsDialog__trueFalseHints(self, hints): ...
    def buildValues(self, policy, hints, valueDict, order): ...

class CapsuleWidgetHintsDialog(DefaultWidgetHintsDialog):
    class CapsuleHintEditor(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
        class OptionPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
            def __init__(self, parent, entry) -> None: ...
            def getResult(self): ...
        def __init__(self, parent, optionsData, factory) -> None: ...
        def _CapsuleHintEditor__addOptionPanel(self): ...
        def buildAddMenu(self, menu): ...
        def getResult(self): ...
    def buildExtras(self, layout): ...
    def buildValues(self, policy, hints, valueDict, order): ...
    def getResult(self): ...

class ColorWidgetHintsDialog(DefaultWidgetHintsDialog):
    def buildValues(self, policy, hints, valueDict, order): ...

class DefaultWidgetHintsDialog(PyQt5.QtWidgets.QDialog):
    TRUEFALSEHINTS: ClassVar[dict] = ...
    def __init__(self, policy, hints) -> None: ...
    def _DefaultWidgetHintsDialog__buildArraySizeInputs(self, policy, hints): ...
    def _DefaultWidgetHintsDialog__trueFalseHints(self, hints): ...
    def accept(self): ...
    def addFromHints(self, name, hints, valueDict, order, default, widgetHints: Incomplete | None = ...): ...
    def buildExtras(self, layout): ...
    def buildStretch(self, layout): ...
    def buildValues(self, policy, hints, valueDict, order): ...
    def getOptionsPolicy(self): ...
    def getResult(self): ...
    def getScrollParent(self): ...
    def getValues(self): ...
    def getWidgetPolicy(self): ...
    def keyPressEvent(self, event): ...

class EnableableDictPolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, inputDict, name, valueOrder: Incomplete | None = ..., hints: Incomplete | None = ..., parent: Incomplete | None = ...) -> None: ...
    def getChildByName(self, name): ...
    def getChildren(self): ...
    def getName(self): ...
    def getNumChildren(self): ...
    def getStateAppearance(self, state): ...
    def getType(self): ...
    def getWidgetHints(self): ...

class EnableableValuePolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, inputList, name, parent: Incomplete | None = ...) -> None: ...
    def getAvailableStates(self): ...
    def getName(self): ...
    def getStateAppearance(self, state): ...
    def getType(self): ...
    def getValue(self): ...
    def getValueState(self): ...
    def getWidgetHints(self): ...
    def setValue(self, value, final: bool = ...): ...
    def setValueState(self, state): ...
    def shouldDisplayState(self): ...

class HelpTextDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, hints, locked: bool = ...) -> None: ...
    def getResult(self): ...

class MappingPopupWidgetHintsDialog(DefaultWidgetHintsDialog):
    class SortableKeyValueWidget(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
        class KeyValuePanel(UI4.Widgets.SortablePanel.SortablePanelBase):
            def __init__(self, parent, entry, isNumber) -> None: ...
            def _KeyValuePanel__forceValidValue(self, value) -> str | float: ...
            def _KeyValuePanel__getValidKey(self, key: str | None) -> str: ...
            def _KeyValuePanel__textChanged(self): ...
            def forceUniquenessCheck(self): ...
            def getValue(self): ...
        def __init__(self, parent, policy, valueList, factory) -> None: ...
        def _SortableKeyValueWidget__addEntry(self): ...
        def _SortableKeyValueWidget__getKeysSet(self) -> set[str]: ...
        def buildAddMenu(self, menu): ...
        def getValue(self): ...
    DEFAULT_NEW_KEY: ClassVar[str] = ...
    DEFAULT_NEW_VALUE: ClassVar[float] = ...
    def buildExtras(self, layout): ...
    def buildValues(self, policy, hints, valueDict, order): ...
    def getResult(self): ...

class ParameterRenameDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, startingName: str, peerNames: typing.Sequence[str]) -> None: ...
    def _ParameterRenameDialog__getRawValues(self) -> Tuple[str, str, str]: ...
    def _ParameterRenameDialog__textChanged(self, value: str): ...
    def _getAdjustedFieldValue(self, text: str) -> str: ...
    def _getAdjustedUniqueDisplayName(self, text: str) -> str: ...
    def _isTextValid(self, text: str) -> bool: ...
    def getResult(self) -> str: ...
    def getValidatingRegex(self) -> str: ...

class PopupWidgetHintsDialog(DefaultWidgetHintsDialog):
    def buildValues(self, policy, hints, valueDict, order): ...
    def getResult(self): ...

class ScriptButtonWidgetHintsDialog(DefaultWidgetHintsDialog):
    def _ScriptButtonWidgetHintsDialog__launchExternalEditor(self): ...
    def buildExtras(self, layout): ...
    def buildValues(self, policy, hints, valueDict, order): ...

class ScriptToolbarWidgetHintsDialog(DefaultWidgetHintsDialog):
    class ScriptToolbarHintEditor(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
        class ButtonPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
            def __init__(self, parent, entry) -> None: ...
            def _ButtonPanel__launchExternalEditor(self): ...
            def getResult(self): ...

        class StretchPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
            def __init__(self, parent) -> None: ...
            def getResult(self): ...
        def __init__(self, parent, buttonData, factory) -> None: ...
        def _ScriptToolbarHintEditor__addButtonPanel(self): ...
        def _ScriptToolbarHintEditor__addStretchPanel(self): ...
        def buildAddMenu(self, menu): ...
        def getResult(self): ...
    def buildExtras(self, layout): ...
    def buildValues(self, policy, hints, valueDict, order): ...
    def getResult(self): ...

class SeparatorWidgetHintsDialog(DefaultWidgetHintsDialog):
    TRUEFALSEHINTS: ClassVar[dict] = ...
    def _SeparatorWidgetHintsDialog__trueFalseHints(self, hints): ...
    def buildValues(self, policy, hints, valueDict, order): ...

def ChangeWidgetType(policy, hints, widgetDisplayType): ...
def GetWidgetDisplayName(widget): ...
def GetWidgetFromDisplayName(displayName): ...
def GetWidgetListForType(policy): ...
def ShowWidgetOptionsDialog(policy, hints): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
import Utils as Utils
from QT4Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class NavigationToolbar(PyQt5.QtWidgets.QFrame):
    _NavigationToolbar__pixmaps: ClassVar[dict] = ...
    def __init__(self, parent, callback: Incomplete | None = ..., maxHistoryLength: int = ...) -> None: ...
    def _NavigationToolbar__backButtonClicked(self): ...
    def _NavigationToolbar__backButtonMenuCallback(self, action): ...
    def _NavigationToolbar__backButtonRightClicked(self): ...
    def _NavigationToolbar__clearHistory(self): ...
    def _NavigationToolbar__forwardButtonClicked(self): ...
    def _NavigationToolbar__forwardButtonMenuCallback(self, action): ...
    def _NavigationToolbar__forwardButtonRightClicked(self): ...
    def _NavigationToolbar__updateState(self): ...
    def clearFuture(self): ...
    def clearPast(self): ...
    def getCallback(self): ...
    def getCurrentEntry(self): ...
    def pushEntry(self, name, meta): ...
    def setCallback(self, callback): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Widgets.SortableGroups as SortableGroups
import UI4.Widgets.SortableGroups
import Utils as Utils
from typing import Set, Tuple

class SortableParamsFormWidget(UI4.Widgets.SortableGroups.SortableGroupsFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _SortableParamsFormWidget__menuAction(self, action): ...
    def buildAddMenu(self, menu): ...
    def updatePanelWidgets(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import Set, Tuple

class ProgressDialog(PyQt5.QtWidgets.QProgressDialog):
    def __init__(self, parent, titleText: Incomplete | None = ..., labelText: Incomplete | None = ..., minimumValue: int = ..., maximumValue: int = ..., interval: int = ..., minimumDuration: int = ...) -> None: ...
    def showEvent(self, event): ...
    def update(self, value: int) -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4Panels.DragOverlay as DragOverlay
import QT4Panels.Edge as Edge
import QT4Panels.Layouts as Layouts
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4Panels.PanelFrame import PanelFrame as PanelFrame
from _typeshed import Incomplete
from typing import Set, Tuple

class PanelLayout(PyQt5.QtWidgets.QWidget):
    def __init__(self, parent, layout: Incomplete | None = ..., dragType: Incomplete | None = ...) -> None: ...
    def _PanelLayout__applyDrag(self): ...
    def _PanelLayout__beginDrag(self, pos, fullEdge): ...
    def _PanelLayout__cancelDrag(self): ...
    def _PanelLayout__resetDragPositions(self): ...
    def _PanelLayout__toggleExpand(self, fullEdge): ...
    def _PanelLayout__updateDrag(self, pos): ...
    def _PanelLayout__updateOverlay(self): ...
    def _PanelLayout__updateTrack(self, pos): ...
    def _applyReal(self): ...
    def addNewFrame(self, coords): ...
    def childEvent(self, event): ...
    def closeFrame(self, frame): ...
    def createDetachLayout(self): ...
    def createPanelFrame(self, count, coords): ...
    def eventFilter(self, child, event): ...
    def findLargestFrame(self): ...
    def getDragType(self): ...
    def getFrames(self): ...
    def getMaximizedFrame(self): ...
    def keyPressEvent(self, event): ...
    def keyReleaseEvent(self, event): ...
    def loadLayout(self, layout): ...
    def mouseMoveEvent(self, event): ...
    def mousePressEvent(self, event): ...
    def mouseReleaseEvent(self, event): ...
    def resizeEvent(self, event): ...
    def saveLayout(self): ...
    def setMaximizedFrame(self, frame): ...
    def __iter__(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
import typing
from typing import Set, Tuple

def CalcTransformMatrixAtExistingTimes(attr: PyFnAttribute.GroupAttribute) -> Tuple[PyFnAttribute.DoubleAttribute, bool]: ...
def CalcTransformMatrixAtTime(attr: object, time: float) -> Tuple[PyFnAttribute.DoubleAttribute, bool]: ...
def CalcTransformMatrixAtTimes(attr: PyFnAttribute.GroupAttribute, times: list[float]) -> Tuple[PyFnAttribute.DoubleAttribute, bool]: ...
def CalcTransformedBoundsAtExistingTimes(xform: PyFnAttribute.Attribute, bounds: PyFnAttribute.DoubleAttribute) -> PyFnAttribute.DoubleAttribute: ...
def CollapseBoundsTimeSamples(bounds: PyFnAttribute.DoubleAttribute) -> PyFnAttribute.DoubleAttribute: ...
def MergeBounds(bounds1: PyFnAttribute.DoubleAttribute, bounds2: PyFnAttribute.DoubleAttribute) -> PyFnAttribute.DoubleAttribute: ...
def PushMatrixAttr(xform: object, matrix: typing.Sequence) -> PyFnAttribute.Attribute: ...
def PushOriginAttr(xform: object) -> PyFnAttribute.Attribute: ...
def PushRotateAttr(xform: object, angle: float, x: float, y: float, z: float) -> PyFnAttribute.Attribute: ...
def PushScaleAttr(xform: object, x: float, y: float, z: float) -> PyFnAttribute.Attribute: ...
def PushTranslateAttr(xform: object, x: float, y: float, z: float) -> PyFnAttribute.Attribute: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes3DAPI.DynamicParameterUtil as DynamicParameterUtil
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibServices as FnGeolibServices
import LoggingAPI as LoggingAPI
import Naming as Naming
import NodegraphAPI as NodegraphAPI
import PyFnAttribute
import Nodes3DAPI.TimingUtils as TimingUtils
import Nodes3DAPI.TransformUtil as TransformUtil
import typing
from Nodes3DAPI_cmodule import BuildAttrListFromDynamicParameterGroup as BuildAttrListFromDynamicParameterGroup
from UI4.FormMaster.GenericAssignParameterPolicy_geolib3 import g_policyRegistrationCallback as g_policyRegistrationCallback
from _typeshed import Incomplete
from types import ModuleType
from typing import ClassVar, Set, Tuple

__attrTypeClasses: dict

class BaseOpChainInterface:
    FnAttribute: ClassVar[ModuleType] = ...
    FnGeolib: ClassVar[ModuleType] = ...
    def __init__(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState) -> None: ...
    def addOpSystemArgs(self, gb: PyFnAttribute.GroupBuilder): ...
    def buildAttrFromParam(self, param: NodegraphAPI.Parameter, multisample: bool = ..., numberType: type[PyFnAttribute.FloatAttribute] = ..., groupInherit: bool = ..., includeEmptyGroups: bool = ...): ...
    def buildAttrListForEnableableParameters(self, enclosingGroupParam: NodegraphAPI.Parameter): ...
    def getExclusiveToNameAndAttribute(self): ...
    def getFrameTime(self) -> float: ...
    def getGraphState(self) -> NodegraphAPI.GraphState: ...
    def getModifiedFrameTime(self) -> float: ...
    def getNumSamples(self) -> int: ...
    def getOutputPortName(self) -> str: ...
    def getShutterClose(self) -> float: ...
    def getShutterOpen(self) -> float: ...
    def getTransformAsAttribute(self) -> PyFnAttribute.GroupAttribute: ...

class NodeTypeBuilder:
    class OpChainInterface(BaseOpChainInterface):
        FAIL: ClassVar[int] = ...
        NO_OP: ClassVar[int] = ...
        SKIP: ClassVar[int] = ...
        def __init__(self, opChainInterface) -> None: ...
        def addInputRequest(self, inputPortName, graphState: NodegraphAPI.GraphState, invalidInputBehavior: int = ...): ...
        def appendOp(self, opType, opArgs: Incomplete | None = ...): ...
        def setExplicitInputRequestsEnabled(self, state): ...
        def setMinRequiredInputs(self, value): ...
    _NodeTypeBuilder__queuedPolicyRootValues: ClassVar[dict] = ...
    _NodeTypeBuilder__registeredTypes: ClassVar[dict] = ...
    def __init__(self, nodeTypeName: str) -> None: ...
    @classmethod
    def SetGenericAssignPolicyRegistrationCallback(cls, callback): ...
    def addInteractiveTransformCallbacks(self, gb: PyFnAttribute.GroupBuilder): ...
    def addMakeInteractiveParameter(self, gb: PyFnAttribute.GroupBuilder): ...
    def addTimingParameters(self, gb: PyFnAttribute.GroupBuilder): ...
    def addTransformParameters(self, gb: PyFnAttribute.GroupBuilder): ...
    def build(self): ...
    def setAddParameterHintsFnc(self, fnc: typing.Callable): ...
    def setAppendToParametersOpChainFnc(self, fnc): ...
    def setBuildOpChainFnc(self, fnc): ...
    def setBuildParametersFnc(self, fnc: typing.Callable): ...
    def setCustomMethod(self, fncName: str, fnc: typing.Callable): ...
    def setGenericAssignRoots(self, paramRoot: str, attrRoot: str): ...
    def setGetInputPortAndGraphStateFnc(self, fnc: typing.Callable): ...
    def setGetScenegraphLocationFnc(self, fnc: typing.Callable): ...
    def setHintsForNode(self, hints: dict): ...
    def setHintsForParameter(self, paramPath: str, hints: dict): ...
    def setInputPortNames(self, names: typing.Sequence[str]): ...
    def setIsHiddenFromMenus(self, state: bool): ...
    def setNodeTypeVersion(self, nodeTypeVersion): ...
    def setNodeTypeVersionUpdateFnc(self, nodeTypeVersion, updateFnc): ...
    def setOutputPortNames(self, names: typing.Sequence[str]): ...
    def setParametersTemplateAttr(self, groupAttr: PyFnAttribute.GroupAttribute, forceArrayNames: tuple = ...): ...

class OpChainInterface(BaseOpChainInterface):
    FAIL: ClassVar[int] = ...
    NO_OP: ClassVar[int] = ...
    SKIP: ClassVar[int] = ...
    def __init__(self, opChainInterface) -> None: ...
    def addInputRequest(self, inputPortName, graphState: NodegraphAPI.GraphState, invalidInputBehavior: int = ...): ...
    def appendOp(self, opType, opArgs: Incomplete | None = ...): ...
    def setExplicitInputRequestsEnabled(self, state): ...
    def setMinRequiredInputs(self, value): ...

class ParametersOpChainInterface(BaseOpChainInterface):
    def __init__(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState) -> None: ...
    def appendOp(self, opType, opArgs: Incomplete | None = ...): ...
    def getOps(self): ...

def _addParameterHints(self, attrName, inputDict): ...
def _getIncomingSceneOpAndLocation(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, transaction): ...
def _getOpChain(self, interface): ...
def _getScenegraphLocation(self, frameTime: Incomplete | None = ...): ...
def _getStaticAttrHintsForIncomingSceneQuery(self, attrPath): ...
def _getStaticDefaultAttrForIncomingSceneQuery(self, attrPath): ...
def _init(self): ...
def _isForcedArray(self, data, groupParam, name): ...
def _paramFromAttr(self, groupParam, groupAttr): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import Utils.EventModule as EventModule
import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import PyFnGeolibProducers
import PyXmlIO as PyXmlIO
import PyUtilModule.RenderManager.RenderTriggers as RenderTriggers
import Utils.UndoStack as UndoStack
import Utils as Utils
import collections
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import Set, Tuple

RENDERCAMERAPATH_VIEWER_BUILTIN: str
RENDERCAMERATYPES: tuple
RENDERCAMERATYPE_RENDERSETTINGS: int
RENDERCAMERATYPE_RENDERSETTINGS_LABEL: str
RENDERCAMERATYPE_SPECIFIC: int
RENDERCAMERATYPE_VIEWER: int
RENDERCAMERATYPE_VIEWER_LABEL: str
RENDERMODES: tuple
RENDERMODE_INTERACTIVE: int
RENDERMODE_LABELS: dict
RENDERMODE_OPTIONS: list
RENDERMODE_PENUP: int
RENDERMODE_PROCESS: int
TILE_PRIORITIZER_NONE: int
TILE_PRIORITIZER_SCANLINE: int
TILE_PRIORITIZER_SPIRAL: int

def ClearSequenceIDMaps(): ...
def GetAvailableSampleRates(): ...
def GetBuffer2DAutoLock(): ...
def GetDefaultSampleRate(): ...
def GetDiskCachingAllowed(): ...
def GetInteractiveSampleRate() -> Tuple[float, float]: ...
def GetLiveRenderOpTreePath() -> str | None: ...
def GetOverscanPadding() -> Tuple[float, float, float, float]: ...
def GetRenderIDPass(): ...
def GetRenderMode() -> int: ...
def GetRenderNodeTypes(): ...
def GetRenderROI(resolution: Incomplete | None = ...) -> None: ...
def GetRenderRawROI() -> None: ...
def GetRenderUseROI() -> bool: ...
def GetRenderViews(): ...
def GetRenderViewsAutoUpdate(): ...
def GetRerenderCamera(renderSettings: Incomplete | None = ...) -> Tuple[int, str]: ...
def GetRerenderMode() -> int: ...
def GetRerenderNodeName() -> str | None: ...
def GetRerenderRenderProducer() -> PyFnGeolibProducers.GeometryProducer | None: ...
def GetRerenderRendererName() -> str | None: ...
def GetSampleRate() -> Tuple[float, float]: ...
def GetSequenceIDMap(mainSequenceID: int) -> collections.OrderedDict: ...
def GetTilePrioritizer(): ...
def IsDefaultROIUsed() -> bool: ...
def IsRenderNode(nodeType): ...
def IsRenderROIAbsolute() -> bool: ...
def IsRerendering() -> bool: ...
def IsSceneGraphMaskEnabled(): ...
def QueryRender(mainSequenceID: int = ...): ...
def ResetRenderROI(): ...
def ResumeRender(mainSequenceID: int = ...): ...
def SetBuffer2DAutoLock(autoLock): ...
def SetDiskCachingAllowed(value): ...
def SetInteractiveSampleRate(newRate: Tuple[float, float]): ...
def SetLiveRenderOpTreePath(filepath: str): ...
def SetOverscanPadding(paddingLBRT: Tuple[float, float, float, float]): ...
def SetRenderIDPass(renderIDPass): ...
def SetRenderMode(renderMode: int): ...
def SetRenderROI(roi: Tuple[float, float, float, float], absolute: bool = ...): ...
def SetRenderROIAbsolute(absolute: bool): ...
def SetRenderRawROI(roi: None): ...
def SetRenderUseROI(useROI: bool): ...
def SetRenderViews(renderViews): ...
def SetRenderViewsAutoUpdate(value): ...
def SetRerenderCamera(rerenderCameraType: int, rerenderCameraPath: Incomplete | None = ...): ...
def SetRerenderMode(renderMode: int): ...
def SetRerenderNodeName(nodeName: str | None): ...
def SetRerendering(isRerendering: bool): ...
def SetSampleRate(newRate: Tuple[float, float]): ...
def SetTilePrioritizer(mode): ...
def SuspendRender(mainSequenceID: int = ...): ...
def TriggerManualRender(): ...
def UpdateSequenceIDMap(mainSequenceID: int, outputName: str, sequenceID: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from _typeshed import Incomplete
from typing import Set, Tuple

class ThreadPool:
    def __init__(self) -> None: ...
    def _ThreadPool__threadFinishedCB(self): ...
    def start(self, thread, priority: Incomplete | None = ...): ...
    def __del__(self) -> None: ...

def GetGlobalThreadPool(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import QT4GLLayerStack as QT4GLLayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from typing import Set, Tuple

class ImageLayerBase:
    def __init__(self, *args, **kwargs) -> None: ...
    def _ImageLayerBase__compositeTimer_timeout_CB(self): ...
    def _ImageLayerBase__slotTimer_timeout_CB(self): ...
    def getDragIndex(self): ...
    def getViewIndexFromWindowPos(self, qpos): ...
    def layerStack(self): ...
    def paintGL(self): ...
    def processEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetBrowser.FileBrowser as FileBrowser
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class BrowserDialog(PyQt5.QtWidgets.QDialog):
    _SETTINGS_GROUP: ClassVar[str] = ...
    def __init__(self) -> None: ...
    def _BrowserDialog__currentTabIndexChanged(self, index): ...
    def _BrowserDialog__selectionValidChange(self, valid): ...
    def _BrowserDialog__wrapAndPad(self, constructor): ...
    def addBrowserTab(self, browserClass, tabName): ...
    def addFileBrowserTab(self): ...
    def getBrowser(self, index): ...
    def getCurrentBrowser(self): ...
    def getCurrentIndex(self): ...
    def getCustomWidgetFrame(self): ...
    def getExtraOptions(self): ...
    def getResult(self): ...
    def readSettings(self, settings): ...
    def setCurrentIndex(self, index): ...
    def setSaveMode(self, saveMode): ...
    def writeSettings(self, settings): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes3DAPI.AbstractTransform as AT
import ConfigurationAPI_cmodule as Configuration
import PyFnAttribute as FnAttribute
import PyFnGeolibServices as FnGeolibServices
import Nodes3DAPI.Node3D as Node3D
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI.TransformUtil as TransformUtil
from Nodes3DAPI.AbstractTransform import AbstractTransform
from typing import Set, Tuple

_ExtraHints: dict
_Parameter_XML: str
_resource_path: str

class PonyCreate(AbstractTransform):
    def __init__(self) -> None: ...
    def _PonyCreate__initName(self): ...
    def _getOpChain(self, interface): ...
    def addParameterHints(self, attrName, inputDict): ...
    def customReset(self): ...
    def getScenegraphLocation(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import UI4.Tabs.Monitor.CatalogGLHelpers as CatalogGLHelpers
import UI4.Util.DrawState as DrawState
import PyFnAttribute as FnAttribute
import UI4.Tabs.Monitor.Layers as Layers
import NodegraphAPI as NodegraphAPI
import PyOpenColorIO as OCIO
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyFnGeolib
import PyQt5.QtCore
import PyQt5.QtGui
import QT4Color as QT4Color
import QT4FormWidgets as QT4FormWidgets
import QT4GLLayerStack as QT4GLLayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import PyResolutionTableFn as ResolutionTable
import UI4 as UI4
import Utils as Utils
from PyUtilModule.VirtualKatana import RenderManager as RenderManager, ScenegraphManager as ScenegraphManager
from QT4GLLayerStack.LayerStack import LayerStack
from QT4Widgets.MenuButton import MenuButton
from UI4.KatanaPrefs.KatanaPrefsObject import KatanaPrefs as KatanaPrefs
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class MonitorWidget(LayerStack):
    IMAGE_MODE_3D: ClassVar[int] = ...
    IMAGE_MODE_DISSOLVE: ClassVar[int] = ...
    IMAGE_MODE_LINEAR_SWIPE: ClassVar[int] = ...
    IMAGE_MODE_NORMAL: ClassVar[int] = ...
    IMAGE_MODE_RECTANGLE_SWIPE: ClassVar[int] = ...
    IMAGE_MODE_SPLIT_HORIZONTAL: ClassVar[int] = ...
    IMAGE_MODE_SPLIT_VERTICAL: ClassVar[int] = ...
    displayItemsChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    drawStateLinkUpdate: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    drawStateUpdated: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    editTransformEnabled: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    editTransformErrored: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    imageModeApplied: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    imageModeChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    manipulatorVisibilityChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    maskChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    monitorAddToolbar: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    monitorPopToolbar: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    monitorRemoveToolbar: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    overlayChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    pixelProbeEnabledVisibilityChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    roiVisibilityChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    swapCatalogViewKeyPressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    syncPanZoomSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ..., catalogClientKey: Incomplete | None = ..., reversedLabels: bool = ...) -> None: ...
    def _MonitorWidget__addManipulator(self, policy): ...
    def _MonitorWidget__addToolbar(self, toolbar, layer): ...
    def _MonitorWidget__buildLayers(self): ...
    def _MonitorWidget__calculateViewRange(self, viewIndex, isZ): ...
    def _MonitorWidget__calculateViewRangeZ_CB(self, drawState): ...
    def _MonitorWidget__calculateViewRange_CB(self, drawState): ...
    def _MonitorWidget__catalog_clientSlotUpdate_CB(self, eventType, eventID): ...
    def _MonitorWidget__catalog_itemDelete_CB(self, eventType, eventID, item, **kwargs): ...
    def _MonitorWidget__catalog_itemImageUpdate_CB(self, eventType, eventID, item, **kwargs): ...
    def _MonitorWidget__catalog_itemPropertyUpdate_CB(self, eventType, eventID, item, **kwargs): ...
    def _MonitorWidget__catalog_rebuild_CB(self, args: list): ...
    def _MonitorWidget__checkEditTranformErrorStatus(self): ...
    def _MonitorWidget__deleteManipulator(self, policy): ...
    def _MonitorWidget__drawStateUpdated_CB(self, drawState): ...
    def _MonitorWidget__getManipulatorDict(self, policy): ...
    def _MonitorWidget__getManipulatorDictForLayer(self, layer): ...
    def _MonitorWidget__initClientManagers(self): ...
    def _MonitorWidget__isManipulatorPresent(self, policy): ...
    def _MonitorWidget__manipulator_animationPathsUpdate_CB(self, eventType, eventID, **kwargs): ...
    def _MonitorWidget__manipulator_update_CB(self, eventType, eventID, policy, isEnabled, **kwargs): ...
    def _MonitorWidget__onRootUpdate(self, locationEvent: PyFnGeolib.LocationEvent, key: str): ...
    def _MonitorWidget__on_node_setViewed(self, args): ...
    def _MonitorWidget__on_pixelProbeColorspaceCombobox_activated(self, index): ...
    def _MonitorWidget__on_pixelProbeModeCombobox_activated(self, index): ...
    def _MonitorWidget__popToolbar(self, toolbar, layer): ...
    def _MonitorWidget__prefChanged_CB(self, eventType, eventID, *args, **kwargs): ...
    def _MonitorWidget__recomputePixelProbe(self, final: bool = ...): ...
    def _MonitorWidget__removeToolbar(self, toolbar, layer): ...
    def _MonitorWidget__stereoValuePolicy_CB(self, changeEvent): ...
    def _MonitorWidget__updateEditTransformedLayers(self): ...
    def _MonitorWidget__updateManipulatorVisibility(self, d): ...
    def _MonitorWidget__updateProbeLabels(self): ...
    def _MonitorWidget__updateROILayer(self): ...
    def createPixelProbeToolbar(self, layout): ...
    def drawDisplayItem(self, viewIndex, additionalTileCacheIDsToLock: Incomplete | None = ...): ...
    def firstPaintGL(self): ...
    def fontChange(self, oldFont: PyQt5.QtGui.QFont): ...
    def frame(self, viewBounds: Incomplete | None = ...): ...
    def getAltOffset(self): ...
    def getAnaglyphSaturation(self): ...
    def getAnamorphDisplayScale(self): ...
    def getBucketOrderPreviewEnabled(self): ...
    def getCatalogClientKey(self): ...
    def getCurrentDrawView(self): ...
    def getCurrentlyViewedViews(self): ...
    def getDataRegionPreviewEnabled(self): ...
    def getDataWindowBounds(self): ...
    def getDisplayItemStats(self, viewIndex, rect: Incomplete | None = ..., ignoreNanInfValues: bool = ..., minInf: Incomplete | None = ..., maxInf: Incomplete | None = ...): ...
    def getDisplayItems(self): ...
    def getDisplayWindowBounds(self): ...
    def getDisplayWindowPreviewEnabled(self): ...
    def getDrawStates(self): ...
    def getDrawStatesLinked(self): ...
    def getEditTransformEnabled(self): ...
    def getEditTransformNode(self): ...
    def getGlobalManipulatorVisibility(self): ...
    def getImageMode(self): ...
    def getImageModeNames(self): ...
    def getLeftView(self): ...
    def getLocalManipulatorVisibility(self, policy): ...
    def getMaskLayer(self): ...
    def getMonoView(self): ...
    def getOverlayItem(self): ...
    def getOverlayMode(self): ...
    def getPixelProbeCenter(self): ...
    def getPixelProbeEnabled(self): ...
    def getPixelProbeRect(self): ...
    def getPixelProbeSize(self): ...
    def getRightView(self): ...
    def getRoiVisible(self): ...
    def getStereoMode(self): ...
    def getStereoValuePolicy(self): ...
    def getSyncPanZoom(self): ...
    def getUnderlayItem(self): ...
    def getViewIndexFromWindowPos(self, qpos): ...
    def getViewSlots(self): ...
    def getVisibleItems(self): ...
    def hideEvent(self, event): ...
    def initManipulators(self): ...
    def isCapableOfNativeStereo(self): ...
    def isOverlayEnabled(self): ...
    def isUnderlayEnabled(self): ...
    def paintGL(self): ...
    def setAltOffset(self, offset): ...
    def setAnaglyphSaturation(self, sat): ...
    def setAnamorphDisplayScale(self, scale): ...
    def setBucketOrderPreviewEnabled(self, isEnabled): ...
    def setDataRegionPreviewEnabled(self, isEnabled): ...
    def setDisplayItem(self, view, catalogItem): ...
    def setDisplayWindowPreviewEnabled(self, isEnabled): ...
    def setDrawStates(self, drawStates): ...
    def setDrawStatesLinked(self, linked): ...
    def setEditTransformEnabled(self, enable): ...
    def setFocusLayer(self, layer, isFocused: bool = ...): ...
    def setGlobalManipulatorVisibility(self, isVisible): ...
    def setImageMode(self, imageMode): ...
    def setLeftView(self, view): ...
    def setLocalManipulatorVisibility(self, policy, isVisible): ...
    def setMonoView(self, view): ...
    def setOverlayEnabled(self, isEnabled): ...
    def setOverlayItem(self, catalogItem): ...
    def setOverlayMode(self, mode): ...
    def setPixelProbeCenter(self, center, final: bool = ...): ...
    def setPixelProbeEnabled(self, enabled): ...
    def setPixelProbeRect(self, lbrt, final: bool = ...): ...
    def setPixelProbeSize(self, size, final: bool = ...): ...
    def setRightView(self, view): ...
    def setRoiVisible(self, visible): ...
    def setStereoMode(self, mode): ...
    def setSyncPanZoom(self, sync): ...
    def setUnderlayEnabled(self, isEnabled): ...
    def setUnderlayItem(self, catalogItem): ...
    def setViewLeft(self): ...
    def setViewMono(self): ...
    def setViewRight(self): ...
    def showEvent(self, event): ...
    def swapDisplayItems(self): ...
    def syncViewTo(self, eyePoint, viewScale): ...
    def update(self): ...

class ScenegraphGotoButton(MenuButton):
    def __init__(self, *args) -> None: ...
    def _ScenegraphGotoButton__copyToClipboard_CB(self): ...
    def _ScenegraphGotoButton__selectInScenegraph_CB(self): ...
    def setScenegraphLocation(self, sgLoc): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import Parser as Parser
from ConditionalStateGrammar.Parser import GetParser as GetParser, ParseAndBuildHintDict as ParseAndBuildHintDict
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.ExternalTools as ExternalTools
import UI4.Util.IconManager as IconManager
import UI4.KatanaPrefs as KatanaPrefs
import UI4.App.KeyboardShortcutManager as KeyboardShortcutManager
import UI4.Widgets.MessageBox as MessageBox
import PyQt5.QtCore
import PyQt5.QtWidgets
import PyUtil.Shelves
import QT4FormWidgets as QT4FormWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Shelves as Shelves
import UI4 as UI4
import Utils as Utils
import typing
from QT4Widgets.FilterablePopupButton import FilterablePopupButton
from _typeshed import Incomplete
from typing import Callable, ClassVar, Set, Tuple

class DataStoreAction(PyQt5.QtWidgets.QAction):
    triggerWithData: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, text, parent, data) -> None: ...
    def _DataStoreAction__trigger(self): ...

class ItemCreateDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, shelf, parent) -> None: ...
    def _ItemCreateDialog__removeWarning(self): ...
    def _ItemCreateDialog__showWarning(self, txt: str): ...
    def _ItemCreateDialog__validateShortcut(self, shortcut: str): ...
    def getResult(self): ...

class ItemEditDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, item) -> None: ...

class ShelfButton(FilterablePopupButton):
    AllShelvesText: ClassVar[str] = ...
    INVALID_KEYBOARD_SHORTCUT: ClassVar[str] = ...
    NO_KEYBOARD_SHORTCUT: ClassVar[str] = ...
    VALID_KEYBOARD_SHORTCUT: ClassVar[str] = ...
    _ShelfButton__instanceMapper: ClassVar[dict] = ...
    _ShelfButton__shelfItemsShortcutID: ClassVar[dict] = ...
    def __init__(self, parent, prefKey: Incomplete | None = ..., shelfQueryCallback: Callable = ..., additionalEnvironmentCallback: typing.Optional[typing.Callable] = ..., shelfSuffix: str = ..., buttonType: Incomplete | None = ..., shortcutContextClassName: str = ...) -> None: ...
    def _ShelfButton__aboutToShow(self): ...
    def _ShelfButton__addMenuAboutToShow(self): ...
    def _ShelfButton__addShelf(self, shelf, nameType): ...
    def _ShelfButton__addShelfItems(self, shelf, shelfName): ...
    def _ShelfButton__addWarning(self, issue: str, path: str, shelfName: str, itemName: str, shortcut: str): ...
    def _ShelfButton__clearWarnings(self): ...
    def _ShelfButton__deleteItem(self, data): ...
    def _ShelfButton__doChosen(self, name, data, checkScope: bool = ...): ...
    def _ShelfButton__doFilterShelf(self, match, name, data): ...
    def _ShelfButton__formatWarningMessage(self, issue: str) -> tuple: ...
    def _ShelfButton__getCurrentShelf(self): ...
    def _ShelfButton__getKeyeventName(self, shelfName: str, itemUniqueName: str) -> str: ...
    def _ShelfButton__getShortcutForShelfItem(self, shelf: Shelves.Shelf, shelfItem: Shelves.ShelfItem) -> str: ...
    def _ShelfButton__isShortcutAlreadyInUse(self, shortcut): ...
    def _ShelfButton__newItem(self): ...
    def _ShelfButton__newShelf(self): ...
    def _ShelfButton__popupWarningDialog(self, title: str, issue: str): ...
    def _ShelfButton__queryShelves(self, forceReload: bool = ...): ...
    def _ShelfButton__registerKeyboardShortcut(self, shelf: PyUtil.Shelves.Shelf, shelfItem: PyUtil.Shelves.ShelfItem, validated: bool = ...): ...
    def _ShelfButton__reloadShelf(self): ...
    def _ShelfButton__reloadShelfIfDirty(self): ...
    def _ShelfButton__rightClick(self, event): ...
    def _ShelfButton__setInstancesDirty(self): ...
    def _ShelfButton__shelfChanged(self, eventName, eventId, *args): ...
    def _ShelfButton__shelfChosen(self, index: Incomplete | None = ...): ...
    def _ShelfButton__shelfCreated(self, eventName, eventID, shelf, **kwargs): ...
    def _ShelfButton__unregisterKeyboardShortcut(self, shelf: PyUtil.Shelves.Shelf, shelfItem: PyUtil.Shelves.ShelfItem): ...
    def _ShelfButton__updateChangedShortcuts(self, shelf: Shelves.Shelf, item: Shelves.ShelfItem, newShortcut: str): ...
    def _ShelfButton__updateScope(self, item: Shelves.ShelfItem, newScope: list): ...
    def _ShelfButton__updateShelfItems(self): ...
    def _ShelfButton__viewSource(self, data): ...
    def closeEvent(self, event: PyQt5.QtCore.QEvent): ...
    def enterEvent(self, event: PyQt5.QtCore.QEvent): ...
    @staticmethod
    def executeShelfScript(widget: PyQt5.QtWidgets.QWidget, shortcut: str): ...
    def getWarnings(self) -> dict: ...
    def keyboardShortcutPressed(self, shortcut): ...
    def leaveEvent(self, event: PyQt5.QtCore.QEvent): ...
    def logWarnings(self, objectHash: str = ..., title: str = ..., popupDialog: bool = ...): ...
    def setDirty(self, dirty: bool = ...): ...
    def unregisterEventHandlers(self): ...
    def validateKeyboardShortcut(self, shelfName: str, name: str, shortcut: str, path: str = ...) -> str: ...

class ShelfCreateDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self) -> None: ...
    def getResult(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import QT4GLLayerStack.Util as Util
from QT4GLLayerStack.LayerStack import Layer as Layer
from typing import ClassVar, Set, Tuple

class EdgeScrollingLayer(QT4GLLayerStack.LayerStack.Layer):
    _INTERVAL: ClassVar[int] = ...
    scroll: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, autoScroll: bool = ...) -> None: ...
    def _EdgeScrollingLayer__move(self): ...
    def _EdgeScrollingLayer__rescale(self, inV): ...
    def _EdgeScrollingLayer__update(self): ...
    def _EdgeScrollingLayer__viewScaleChanged(self, vs): ...
    def processEvent(self, event): ...
    def setLayerStack(self, layerStack): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
import typing
from QT4Widgets.PythonConsole import FullInteractivePython as FullInteractivePython
from UI4.KatanaPrefs.KatanaPrefsObject import KatanaPrefs as KatanaPrefs
from UI4.Tabs.BaseTab import BaseTab
from UI4.Util.PythonSyntaxHighlighter import PythonSyntaxHighlighter as PythonSyntaxHighlighter
from UI4.Util.PythonWidgetIntrospector import PythonWidgetIntrospector as PythonWidgetIntrospector
from typing import Set, Tuple

PYTHONRC_FILENAME: str
_Environment: None

class EnhancedTerminalTab(BaseTab):
    def __init__(self, parent) -> None: ...
    def _EnhancedTerminalTab__on_commandWidget_editingFinished(self): ...
    def _EnhancedTerminalTab__on_prefChanged(self, eventType: str | None, eventID: typing.Hashable, prefKey: str, prefValue: object): ...
    def _EnhancedTerminalTab__on_pythonTab_exposeObject(self, eventType: str, eventID: object, objName: str, objInstance: object): ...
    def _EnhancedTerminalTab__on_scriptWidget_aboutToExecuteCode(self, sourceCode: C[str]): ...
    def clear(self): ...
    def getMenuBar(self) -> PyQt5.QtWidgets.QMenuBar | None: ...
    def printMessage(self, message: str): ...

def _HandleLayoutActivated(eventType: str | None, eventID: object): ...
def _HandleLayoutsSaved(eventType: str | None, eventID: object): ...
def _RestoreCommandAreaContentsFromPreferences(): ...
def _StoreCommandAreaContentsInPreferences(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import NodegraphAPI as NodegraphAPI
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

class KeyDrawingLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, treeWidget, *args, **kwargs) -> None: ...
    def _KeyDrawingLayer__currentTimeCB(self, args: Incomplete | None = ...): ...
    def _KeyDrawingLayer__drawWindowSpaceText(self, text: str, textColor: None, left: int, baseline: int, center: bool = ...): ...
    def _KeyDrawingLayer__getTreeItemStartY(self): ...
    def _KeyDrawingLayer__hitTestBoxForChildren(self, firstChildTop, item, startT, endT, hitAreaBottom, hitAreaTop, hitList): ...
    def _KeyDrawingLayer__paintItemChildrenGL(self, startY, item, visibleArea, degenerate, highlightColor, topLevel: bool = ...): ...
    def _KeyDrawingLayer__paintKey(self, t, y0, y1, isLeaf, degenerate, selected: bool = ..., reduced: bool = ..., potential: bool = ..., conflict: bool = ...): ...
    def _KeyDrawingLayer__paintTimeCursor(self, t, lineRgba, textRgba, x0, x1, yBottom, yBase): ...
    def _KeyDrawingLayer__paintTimebar(self, x0, x1, yTop, yBase, yBottom, palette): ...
    def _KeyDrawingLayer__timeRangeCB(self, *args): ...
    def clearKeysPotential(self): ...
    def getTextScale(self) -> float: ...
    def hitTestBox(self, hitArea: None) -> list: ...
    def hitTestPoint(self, worldPt): ...
    def hitTestPointForItem(self, worldPt): ...
    def initializeGL(self): ...
    def paintGL(self): ...
    def setGhostTime(self, t): ...
    def setKeysPotential(self, potentials, conflict: bool = ...): ...
    def setTextScale(self, textScale: float): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import UI4.NodeMaster.NodeInteractionDelegateManager as NodeInteractionDelegateManager
import NodegraphAPI as NodegraphAPI
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import UI4.NodeMaster.NodeInteractionDelegateManager
import Utils as Utils
from typing import Set, Tuple

class FileInDelegate(UI4.NodeMaster.NodeInteractionDelegateManager.Delegate):
    def _FileInDelegate__dialogPrompt(self): ...
    def _FileInDelegate__validCatalogDrop(self, targetNode, event): ...
    def _FileInDelegate__validNodeDrop(self, targetNode, event): ...
    def acceptsDrop(self, targetNode, event): ...
    def processDrop(self, targetNode, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
import UI4.FormMaster.States as States
import UI4.FormMaster.ParameterPolicy
import Utils as Utils
from UI4.FormMaster.GroupParameterPolicy import GroupParameterPolicy as GroupParameterPolicy
from UI4.FormMaster.ScalarParameterPolicy import ScalarParameterPolicy as ScalarParameterPolicy
from _typeshed import Incomplete
from typing import Set, Tuple

class EnableableGroupParameterPolicy(GroupParameterPolicy):
    def __init__(self, param, parentPolicy) -> None: ...
    def getAvailableStates(self): ...
    def getValueState(self): ...
    def getWidgetHints(self): ...
    def setValueState(self, state): ...
    def shouldDisplayState(self): ...

class EnableableScalarParameterPolicy(ScalarParameterPolicy):
    def __init__(self, param, parent) -> None: ...
    def _EnableableScalarParameterPolicy__initFromDefault(self): ...
    def _handleParamFinalized(self, args): ...
    def getAvailableStates(self): ...
    def getValueState(self): ...
    def getWidgetHints(self): ...
    def setCurve(self, curve): ...
    def setCurveAutoKey(self, autoKey): ...
    def setCurveEnabled(self, state): ...
    def setCurveKey(self, state): ...
    def setExpression(self, rawExpr): ...
    def setExpressionEnabled(self, flag): ...
    def setValue(self, value, final: bool = ...): ...
    def setValueState(self, state): ...
    def shouldDisplayState(self): ...

class EnableableScalarPolicyDelegate(UI4.FormMaster.ParameterPolicy.ParameterPolicyDelegate):
    def __init__(self, exclude: Incomplete | None = ..., groupEnable: Incomplete | None = ...) -> None: ...
    def createPolicy(self, parentPolicy, param): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import PyFnGeolibProducers as FnGeolibProducers
import QT4FormWidgets as QT4FormWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtWidgets as QtWidgets
import RenderingAPI as RenderingAPI
import Utils as Utils
from QT4FormWidgets.FilterablePopupFormWidget.FilterablePopupFormWidget import Popup
from QT4Widgets.MenuButton import MenuButton as MenuButton
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class LookFileMaterialFilterPopup(Popup):
    def __init__(self, *args) -> None: ...
    def _LookFileMaterialFilterPopup__assetValueChangedEvent(self, *args): ...
    def _LookFileMaterialFilterPopup__cachesFlushed(self, *args, **kwargs): ...
    def _refreshContents(self): ...

class ShaderFilterPopup(Popup):
    _ShaderFilterPopup__TAILPAT: ClassVar[builtin_function_or_method] = ...
    def __init__(self, valuePolicy, parent: Incomplete | None = ...) -> None: ...
    @staticmethod
    def _ShaderFilterPopup__getKey(o): ...
    def _ShaderFilterPopup__locationFilterCallback(self, state, name, meta): ...
    def _ShaderFilterPopup__reloadShaders(self): ...
    def _ShaderFilterPopup__shadersReloaded(self, args): ...
    def _refreshContents(self): ...
    def _shouldIncludeShader(self, name, location): ...

class ShaderTypeFilterPopup(Popup):
    def __init__(self, *args) -> None: ...
    def _getShaderTypesXML(self): ...
    def _refreshContents(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.FormMaster.Editors.NodeGroup
from UI4.FormMaster.Editors.NodeGroup import NodeGroupFormWidget as NodeGroupFormWidget
from typing import Set, Tuple

class Node2DGroupFormWidget(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _createChildWidget(self, policy, parentWidget, factory, index): ...
    def _popdownCreated(self, popdown): ...
    def getPopdownWidget(self): ...
    def populateDecorations(self, popdown, layout): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.HintUtils as HintUtils
import QT4FormWidgets.InputWidgets as InputWidgets
import QT4FormWidgets.PaintingUtils as PaintingUtils
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
from QT4FormWidgets.BaseValueFormWidget import BaseValueFormWidget as BaseValueFormWidget
from QT4FormWidgets.FormWidget import FormWidget as FormWidget
from QT4FormWidgets.PopupFormWidget import PopupFormWidget as PopupFormWidget
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from typing import Set, Tuple

class BooleanFormWidget(PopupFormWidget):
    def _assignValue(self, value): ...
    def _interpretOptions(self, options): ...
    def _interpretValue(self, value): ...

class MappingPopupFormWidget(PopupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _assignValue(self, value): ...
    def _getIndexFromValue(self, _value): ...
    def _interpretOptions(self, options): ...
    def _interpretValue(self, value): ...

class PopupFormWidget(BaseValueFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _PopupFormWidget__on_defaultButton_clicked(self): ...
    def _PopupFormWidget__on_lineEdit_textChanged(self, text): ...
    def _PopupFormWidget__updateComboBox(self, value): ...
    def _allowsCustomInput(self): ...
    def _assignValue(self, value): ...
    def _buildControlWidget(self, layout): ...
    def _checkControlWidget(self): ...
    def _getIndexFromValue(self, value: str) -> int: ...
    def _interpretOptions(self, options: str | list | tuple | None) -> list[str]: ...
    def _interpretValue(self, value): ...
    def _lockChanged(self, state): ...
    def _populateComboBox(self): ...
    def _setControlWidgetValue(self, value: str): ...
    def _updateControlWidget(self): ...
    def _updateWithHints(self, originalHints, hints): ...
    def getOptions(self): ...
    def setOptions(self, options): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyUtilModule.RenderManager as RenderManager
import Utils as Utils
from QT4FormWidgets.GroupFormWidget import GroupFormWidget
from QT4GLLayerStack.RectangleLayer import RectangleLayer
from UI4.FormMaster.Editors.Layers.LayerWithTransform import LayerWithTransform as LayerWithTransform
from UI4.FormMaster.Editors.Layers.PolicyHelpers import GetPolicyState as GetPolicyState, GetPolicyStateColor as GetPolicyStateColor
from UI4.Util.GLDrawingRoutines import drawSmoothHandle as drawSmoothHandle, drawSmoothPoly as drawSmoothPoly
from UI4.Widgets.MonitorManipulatorButton import MonitorManipulatorButton as MonitorManipulatorButton
from UI4.Widgets.ResolutionComboBox import ResolutionComboBox as ResolutionComboBox
from _typeshed import Incomplete
from typing import Set, Tuple

class ReadOnlySimpleRectManipulatorLayer(SimpleRectManipulatorLayer):
    def defaultProcessEvent(self, event): ...

class RectEditorFormWidget(GroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _RectEditorFormWidget__copy_fromMonitorROI_CB(self): ...
    def _RectEditorFormWidget__copy_toMonitorROI_CB(self): ...
    def _RectEditorFormWidget__menuAboutToShow(self, menu): ...
    def _RectEditorFormWidget__on_resolutionComboBox_itemChosen(self, text: str, meta: str): ...
    def _RectEditorFormWidget__updateComboBox(self, valuePolicyEvent: Incomplete | None = ...): ...
    def _buildControlWidget(self, layout): ...
    def _freeze(self): ...
    def _participatesInLabelAlignment(self) -> bool: ...
    def _thaw(self): ...

class RectManipulatorLayer(RectangleLayer):
    def __init__(self, valuePolicy, *args, **kwargs) -> None: ...
    def _RectManipulatorLayer__valuePolicy_CB(self, arg: Incomplete | None = ...): ...
    def _dothaw(self): ...
    def getDataWindow(self): ...
    def getDisplayWindow(self): ...
    def setRectangle(self, rect): ...

class SimpleRectManipulatorLayer(LayerWithTransform, QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, valuePolicy, *args, **kwargs) -> None: ...
    def _SimpleRectManipulatorLayer__valuePolicy_CB(self, arg: Incomplete | None = ...): ...
    def _dothaw(self): ...
    def defaultProcessEvent(self, event): ...
    def drawBoundsHandles(self, pick: bool = ...): ...
    def drawOutline(self, pick: bool = ...): ...
    def getDataWindow(self): ...
    def getDisplayWindow(self): ...
    def getOriginLock(self): ...
    def getRect(self): ...
    def getRectStates(self): ...
    def getValuePolicy(self): ...
    def paintGL(self): ...
    def pickBoundsHandle(self, x, y): ...
    def pickOutline(self, x, y): ...
    def processDragHandleEvent(self, event): ...
    def setOriginLock(self, isLocked): ...
    def setRect(self, rect, final): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import LightListPopup as LightListPopup, SceneGraphBookmarkButton as SceneGraphBookmarkButton, SceneGraphTabColumn as SceneGraphTabColumn, SceneGraphTabItems as SceneGraphTabItems, SceneGraphTabNameItemDelegate as SceneGraphTabNameItemDelegate
from UI4.Tabs.SceneGraphTab.SceneGraphTab import SceneGraphTab as SceneGraphTab
from typing import Set, Tuple

PluginRegistry: list



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import UI4 as UI4
from _typeshed import Incomplete
from typing import Set, Tuple

def GetImagePath(title: Incomplete | None = ..., path: Incomplete | None = ...): ...
def SetLoadPath(path): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import Utils as Utils
from typing import Set, Tuple

def InitializePluginManager(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import QT4Widgets.WidgetUtils as WidgetUtils
from QT4Widgets.CustomMenu import CustomMenu as CustomMenu
from typing import ClassVar, Set, Tuple

class PopdownLabel(PyQt5.QtWidgets.QLabel):
    buildMenuSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...
    def buildMenu(self, menu): ...
    def enterEvent(self, ev): ...
    def leaveEvent(self, ev): ...
    def minimumSizeHint(self): ...
    def mousePressEvent(self, ev): ...
    def paintEvent(self, ev): ...
    def sizeHint(self): ...
    def updateStyle(self, isSetToDefault): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnGeolibServices.ExpressionMath as ExpressionMath
import PyFnGeolibServices as FnGeolibServices
import NodegraphAPI as NodegraphAPI
import PyFCurve as PyFCurve
import PyQt5.QtCore
import QT4Browser as QT4Browser
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.MultiStateBadge
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
from QT4FormWidgets.NumberFormWidget import NumberFormWidget
from typing import ClassVar, Set, Tuple

class DualInputKatanaNumberFormWidget(KatanaNumberFormWidget):
    def _DualInputKatanaNumberFormWidget__altPolicyValueChanged(self, event): ...
    def _DualInputKatanaNumberFormWidget__evalConversion(self, expr, value): ...
    def _buildControlWidget(self, layout): ...
    def _updateControlWidget(self): ...
    def valueChangedEvent(self, event): ...

class EditSignalingNumberFormWidget(KatanaNumberFormWidget):
    class _SignalingToggleStateBadge(QT4FormWidgets.MultiStateBadge.ToggleStateBadge):
        pressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def mousePressEvent(self, event): ...
    userEdited: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def _EditSignalingNumberFormWidget__userEdited(self, *args): ...
    def _buildControlWidget(self, layout): ...
    def _buildStateBadge(self, policy): ...
    def _popdownCreated(self, popdown): ...
    def labelSliderDrag(self, pos, modifiers): ...
    def labelSliderEnd(self, pos, modifiers): ...
    def supportsStickyScrub(self) -> bool: ...

class KatanaNumberFormWidget(NumberFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _KatanaNumberFormWidget__bakeToFCurve(self): ...
    def _KatanaNumberFormWidget__exportCurveToFCurveXML(self): ...
    def _KatanaNumberFormWidget__importCurveFromFCurveFile(self): ...
    def _addExportMenuActions(self, menu): ...
    def _addExtraMenuAction(self, menu): ...
    def _addImportMenuActions(self, menu): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils as Utils
import types
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import Set, Tuple

class LayeredMenu:
    def __init__(self, populateCallback: types.MethodType, actionCallback: types.MethodType, keyboardShortcut: str, alwaysPopulate: bool = ..., onlyMatchWordStart: bool = ...) -> None: ...
    def addEntry(self, value: object, labelText: Incomplete | None = ..., color: Incomplete | None = ..., size: Incomplete | None = ...): ...
    def alwaysPopulate(self): ...
    def clear(self): ...
    def getEntries(self): ...
    def getKeyboardShortcut(self): ...
    def getLastChosenValue(self): ...
    def isPopulated(self): ...
    def onEntryChosen(self, value): ...
    def onlyMatchWordStart(self) -> bool: ...
    def populate(self): ...

class LayeredMenuEntry:
    def __init__(self, value: object, text: Incomplete | None = ..., color: Incomplete | None = ..., size: Incomplete | None = ...) -> None: ...
    def getColor(self): ...
    def getSize(self): ...
    def getText(self): ...
    def getValue(self): ...

def GetLayeredMenu(id: str): ...
def RegisterLayeredMenu(layeredMenu, layeredMenuID): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4 as UI4
from _typeshed import Incomplete
from typing import Set, Tuple

POLICY_STATE_CURVE_FLOATING: int
POLICY_STATE_CURVE_KEY: int
POLICY_STATE_CURVE_NO_KEY: int
POLICY_STATE_DEFAULT: int
POLICY_STATE_EXPRESSION: int
POLICY_STATE_LOCKED: int
POLICY_STATE_NORMAL: int

def GetPolicyState(valuePolicy): ...
def GetPolicyStateColor(state: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4Widgets.FilterablePopupButton import FilterablePopupButton
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class NodeChooserButton(FilterablePopupButton):
    buttonClicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    nodeSelected: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _NodeChooserButton__filterItemCallback(self, value: bool, name, meta) -> bool: ...
    def addPopupWindowButton(self, text: str): ...
    def addSceneNodesCheckbox(self, text: str = ..., defaultValue: bool = ...): ...
    def getNodeNames(self) -> list[str | None]: ...
    def getNodeTypeName(self) -> str | None: ...
    def on_aboutToShow(self): ...
    def on_button_clicked(self): ...
    def on_itemChosen(self, name, meta): ...
    def setNodeNames(self, nodeNames: list[str | None]): ...
    def setNodeTypeName(self, nodeTypeName: str | None): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import KatanaResources as KatanaResources
import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.ScenegraphBookmarkManager as ScenegraphBookmarkManager
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import UI4 as UI4
from PyUtilModule.WorkingSetManager import WorkingSetManager as WorkingSetManager
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class BookmarkAction(PyQt5.QtWidgets.QAction):
    _BookmarkAction__iconFile: ClassVar[str] = ...
    icon: ClassVar[None] = ...
    def __init__(self, bookmarkDict: dict, *args) -> None: ...
    def _BookmarkAction__activated_CB(self): ...

class SceneGraphBookmarkButton(ToolbarButton):
    _SceneGraphBookmarkButton__iconFile: ClassVar[str] = ...
    _SceneGraphBookmarkButton__rolloverIconFile: ClassVar[str] = ...
    def __init__(self, parent, *args) -> None: ...
    def _SceneGraphBookmarkButton__clearBookmarks(self): ...
    def _SceneGraphBookmarkButton__clearWorkingSets(self): ...
    def _SceneGraphBookmarkButton__createBookmark(self): ...
    def _SceneGraphBookmarkButton__exportBookmarks(self): ...
    def _SceneGraphBookmarkButton__importBookmarks(self): ...
    def _SceneGraphBookmarkButton__organizeBookmarks(self): ...
    def _SceneGraphBookmarkButton__saveAndPublishBookmarks(self, xml: str, filePathOrAssetId: str, extraOptions: dict = ...): ...
    def _SceneGraphBookmarkButton__updateMenu(self): ...
    def _SceneGraphBookmarkButton__writeBookmarksFile(self, xml, filename, confirmOverwrite: bool = ...): ...

class SceneGraphBookmarkCreationDialog(PyQt5.QtWidgets.QDialog):
    DEFAULT_HEIGHT: ClassVar[int] = ...
    DEFAULT_WIDTH: ClassVar[int] = ...
    MAX_PROPORTION_OF_SCREEN_SIZE: ClassVar[float] = ...
    PAD_HEIGHT: ClassVar[int] = ...
    PAD_WIDTH: ClassVar[int] = ...
    VERTICAL_OFFSET: ClassVar[int] = ...
    def __init__(self, globalPos: PyQt5.QtCore.QSize) -> None: ...
    def _SceneGraphBookmarkCreationDialog__calculateGeometry(self) -> PyQt5.QtCore.QRect: ...
    def _SceneGraphBookmarkCreationDialog__createLabelledComboBox(self, labelText, objectName) -> Tuple[PyQt5.QtWidgets.QWidget, PyQt5.QtWidgets.QWidget]: ...
    def _SceneGraphBookmarkCreationDialog__createWorkingSetsCheckBoxes(self, parentWidget: PyQt5.QtWidgets.QWidget) -> list[PyQt5.QtWidgets.QCheckBox]: ...
    def _SceneGraphBookmarkCreationDialog__createWorkingSetsFrame(self) -> PyQt5.QtWidgets.QFrame: ...
    def _SceneGraphBookmarkCreationDialog__deselectAllWorkingSets(self): ...
    def _SceneGraphBookmarkCreationDialog__getCurrentBookmarkFullName(self) -> str: ...
    def _SceneGraphBookmarkCreationDialog__getCurrentBookmarkName(self) -> str: ...
    def _SceneGraphBookmarkCreationDialog__getCurrentFolderName(self) -> str: ...
    def _SceneGraphBookmarkCreationDialog__getScreenGeometry(self, globalPos: PyQt5.QtCore.QPoint, desktop: Incomplete | None = ...) -> PyQt5.QtCore.QRect: ...
    def _SceneGraphBookmarkCreationDialog__getSelectedWorkingSets(self) -> list[str]: ...
    def _SceneGraphBookmarkCreationDialog__on_bookmarkNameComboBox_changed(self): ...
    def _SceneGraphBookmarkCreationDialog__on_folderComboBox_changed(self): ...
    def _SceneGraphBookmarkCreationDialog__on_workingSetCheckBoxes_changed(self): ...
    def _SceneGraphBookmarkCreationDialog__positionRectInRect(self, rect: PyQt5.QtCore.QRect, enclosingRect: PyQt5.QtCore.QRect) -> Tuple[int, int]: ...
    def _SceneGraphBookmarkCreationDialog__repopulateBookmarkNameWidget(self): ...
    def _SceneGraphBookmarkCreationDialog__selectAllWorkingSets(self): ...
    def _SceneGraphBookmarkCreationDialog__updateSaveButton(self): ...
    def _SceneGraphBookmarkCreationDialog__updateSelectedWorkingSets(self): ...
    def getResult(self) -> dict: ...

class SceneGraphBookmarkItemDelegate(PyQt5.QtWidgets.QItemDelegate):
    def editorEvent(self, event, model, option, index): ...

class SceneGraphBookmarkOrganizationDialog(PyQt5.QtWidgets.QDialog):
    class BookmarkItem(PyQt5.QtWidgets.QTreeWidgetItem):
        _BookmarkItem__iconFile: ClassVar[str] = ...
        icon: ClassVar[None] = ...
        def __init__(self, shortName, fullName, parent) -> None: ...
        def _BookmarkItem__delete_CB(self): ...
        def buildContextMenu(self, menu): ...

    class FolderItem(PyQt5.QtWidgets.QTreeWidgetItem):
        _FolderItem__iconFile: ClassVar[str] = ...
        icon: ClassVar[None] = ...
        def __init__(self, folderName, parent) -> None: ...
    def __init__(self, folders, bookmarks) -> None: ...

class VerticalScrollArea(PyQt5.QtWidgets.QScrollArea):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, childWidget: PyQt5.QtWidgets.QWidget) -> None: ...
    def resizeEvent(self, event): ...
    def sizeHint(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnGeolibServices as FnGeolibServices
import KatanaResources as KatanaResources
import NodegraphAPI as NodegraphAPI
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def GetGenericAssignFiles() -> list[None]: ...
def GetGenericAssignNodeTypes() -> dict: ...
def InitGenericAssignNodeTypes(searchPaths: Incomplete | None = ...): ...
def RegisterGenericAssignNodeTypes(searchPaths: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnGeolibProducers
import GeoAPI.Util as Util
import PyFnGeolibServices.XFormUtil as XFormUtil
from typing import Set, Tuple

def ProducerLocalTransform(producer: PyFnGeolibProducers.GeometryProducer): ...
def ProducerWorldBounds(producer: PyFnGeolibProducers.GeometryProducer): ...
def ProducerWorldTransform(producer: PyFnGeolibProducers.GeometryProducer): ...
def UnionBounds(bounds1, bounds2): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils.EventModule as EventModule
import PyFCurve as PyFCurve
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4Widgets as QT4Widgets
import QTFCurve as QTFCurve
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import UI4.Widgets.GradientLayer
import Utils as Utils
from QT4FormWidgets.GroupFormWidget import GroupFormWidget
from QTFCurve.FCurveListView import FCurveListView
from typing import ClassVar, Set, Tuple

class ContextMenuFCurveListView(FCurveListView):
    curveContextMenu: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    curveStateToggle: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...
    def contextMenuEvent(self, event): ...
    def mousePressEvent(self, event): ...

class CurvesFormWidget(GroupFormWidget, UI4.Widgets.GradientLayer.GradientLayerBundleManager):
    def __init__(self, parent, policy, factory) -> None: ...
    def _CurvesFormWidget__actionBegin_CB(self, qstringName): ...
    def _CurvesFormWidget__actionEnd_CB(self): ...
    def _CurvesFormWidget__actuallyReloadCurves(self): ...
    def _CurvesFormWidget__addFCurveKeyNondisruptive(self, curve, x): ...
    def _CurvesFormWidget__curveChanged(self, curve, final): ...
    def _CurvesFormWidget__curveContextMenu(self, curve, pos): ...
    def _CurvesFormWidget__curveCopy(self): ...
    def _CurvesFormWidget__curvePaste(self): ...
    def _CurvesFormWidget__curvePropertyChanged(self, curve, key, value): ...
    def _CurvesFormWidget__curveSetDefault(self, curve, policy): ...
    def _CurvesFormWidget__curveSetLocal(self, curve, policy): ...
    def _CurvesFormWidget__curveStateToggle(self, curve): ...
    def _CurvesFormWidget__curveUndo_CB(self, eventType, eventID, **kwargs): ...
    def _CurvesFormWidget__homeButton_clicked_callback(self): ...
    def _CurvesFormWidget__makeAnimated(self): ...
    def _CurvesFormWidget__makeConstant(self): ...
    def _CurvesFormWidget__setCurveStateColor(self, curve, rgb, state, brightness): ...
    def _CurvesFormWidget__setupEventHandlers(self, enabled): ...
    def _CurvesFormWidget__timeChangedCB(self, args): ...
    def _CurvesFormWidget__toggleKeyframe(self): ...
    def _buildControlWidget(self, hbox): ...
    def _freeze(self): ...
    def _popdownCreated(self, popdown): ...
    def _registerCurve(self, curveName, curveAndLayerInfo): ...
    def _reloadCurves(self): ...
    def _setCurveColors(self, curve, rgb): ...
    def _setCurveKey(self, value): ...
    def _thaw(self): ...
    def _unloadCurves(self): ...
    def _updateGraphView(self): ...
    def contextMenuEvent(self, event): ...
    def fitToViewport(self): ...
    def getCurvesToLoad(self): ...
    def getEditor(self): ...
    def getPolicyForCurve(self, curve): ...

class FCurveMaster(PyQt5.QtWidgets.QWidget):
    def __init__(self, parent, policyForCurveCallbackObject) -> None: ...
    def _FCurveMaster__itemClicked_CB(self, item, column): ...
    def addCustomColumn(self, name, defaultValue, valueList: list = ...): ...
    def event(self, event): ...
    def getCurves(self): ...
    def getGraphView(self): ...
    def getListView(self): ...
    def getValueEdit(self): ...

class StateBadgeItemDelegate(PyQt5.QtWidgets.QItemDelegate):
    def __init__(self, parent, policyForCurveCallbackObject, autoKeyColumn) -> None: ...
    def paint(self, painter, option, index): ...
    def paintAutoKeyColumn(self, painter, option, index): ...
    def paintNameColumn(self, painter, option, index): ...
    def sizeHint(self, option, index): ...

class _SimpleObserver(PyFCurve.FCurveObserver):
    def __init__(self) -> None: ...
    def beginValueChange(self, curve): ...
    def curveChanged(self, curve): ...
    def curvePropertyChanged(self, curve, key, value): ...
    def emitter(self): ...
    def endValueChange(self, curve): ...
    def keyframePropertyChanged(self, *args, **kwargs): ...
    def mute(self, muteFlag): ...
    def segmentPropertyChanged(self, *args, **kwargs): ...
    def tangentPropertyChanged(self, *args, **kwargs): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.DrawState as DrawState
import PyOpenColorIO as OCIO
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
from _typeshed import Incomplete
from typing import Set, Tuple

class DrawStateColorLineEdit(PyQt5.QtWidgets.QLineEdit):
    def __init__(self, mode, index, drawState, *args) -> None: ...
    def _DrawStateColorLineEdit__activatedCB(self): ...
    def _DrawStateColorLineEdit__drawStateUpdated_CB(self, drawState: Incomplete | None = ...): ...
    def fontChange(self, oldFont: PyQt5.QtGui.QFont): ...

def AddDisplayVisualizationActionsToMenu(menu, drawState): ...
def AddImageChannelActionsToMenu(menu, drawState): ...
def AddPixelCheckControlsToMenu(menu, drawState): ...
def AddViewControlsToMenu(menu, drawState): ...
def AddZoomActionsToMenu(menu, monitorWidget): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PluginSystemAPI as PluginSystemAPI
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import Utils as Utils
from QT4FormWidgets.FilterablePopupFormWidget import FilterablePopupFormWidget
from QT4FormWidgets.FilterablePopupFormWidget.FilterablePopupFormWidget import Popup, PopupButton
from typing import Set, Tuple

class PluginPopupFormWidget(FilterablePopupFormWidget):
    class PluginPopup(Popup):
        def __init__(self, *args) -> None: ...
        def _PluginPopup__cachesFlushed(self, *args, **kwargs): ...
        def _refreshContents(self): ...

    class PluginPopupButton(PopupButton):
        def __init__(self, valuePolicy) -> None: ...
        def _buildPopupWindow(self): ...
        def sizeHint(self): ...
    def _buildLabel(self, labelText, pos: int = ...): ...
    def _buildPopupButton(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel as SortablePanel
import UI4 as UI4
import UI4.FormMaster.Editors.UserParametersDialogs
import UI4.Widgets.SortablePanel
import Utils as Utils
from Nodes3DAPI.DynamicParameterUtil import CreateParamNameFromAttrPath as CreateParamNameFromAttrPath
from UI4.FormMaster.Editors.UserParametersDialogs import ParameterRenameDialog as ParameterRenameDialog
from UI4.FormMaster.ParameterPolicy import CreateParameterPolicy as CreateParameterPolicy
from typing import ClassVar, Set, Tuple

class AttributeEntryPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    _AttributeEntryPanel__INVERSEPALETTE: ClassVar[None] = ...
    def __init__(self, parent, name, policy, widgetFactory) -> None: ...
    def _AttributeEntryPanel__buildWrenchMenu(self): ...
    def _AttributeEntryPanel__pathChangedEvent(self, event): ...
    def _AttributeEntryPanel__rename(self): ...
    def freeze(self): ...
    def getValuePolicy(self): ...
    def getWidget(self): ...
    def thaw(self): ...

class OverrideRenameDialog(UI4.FormMaster.Editors.UserParametersDialogs.ParameterRenameDialog):
    def getValidatingRegex(self): ...

class SortableAttributeDropEditor(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _SortableAttributeDropEditor__attrDropped(self, attr, path, hints): ...
    def _SortableAttributeDropEditor__checkAttrIsValid(self, attr): ...
    def _SortableAttributeDropEditor__displayDuplicateEntryWarning(self, duplicateEntryName, widgetType): ...
    def _SortableAttributeDropEditor__getAcceptablePath(self, path): ...
    def _SortableAttributeDropEditor__getAcceptablePathDisplayName(self): ...
    def _SortableAttributeDropEditor__getOverrideAttributeEntries(self): ...
    def _SortableAttributeDropEditor__getRootPolicy(self): ...
    def _SortableAttributeDropEditor__menuAction(self, action): ...
    def _SortableAttributeDropEditor__on_attrDropped(self, attr, path, hints): ...
    def _SortableAttributeDropEditor__on_attrDroppedWithCoAttributes(self, attr, path, hints, coAttrs): ...
    def _buildControlWidget(self, hbox): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def buildAddMenu(self, menu): ...
    def panelDeleted(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def updatePanels(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from QT4FormWidgets.FormWidget import AlignChildLabelWidths as AlignChildLabelWidths, AlignLeftControlWidths as AlignLeftControlWidths, FormWidget as FormWidget, ScrubbingStates as ScrubbingStates
from typing import Set, Tuple

__init__: list

class NullFormWidget(FormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _participatesInLabelAlignment(self): ...
    def setVisible(self, state, checkVisOps: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes2DAPI as Nodes2DAPI
import PyQt5.QtCore as QtCore
import Utils as Utils
from typing import Set, Tuple

def DirtyBufferRects(frameBufferObj, updateRects): ...
def DrawBuffers(widget, buffers, drawWindow, displayRequest, overlayMode, additionalTileCacheIDsToLock): ...
def FlushTexturePool(): ...
def GetTexturePoolSizeMB(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from PyUtilModule.VirtualKatana import FaceSelectionManager as FaceSelectionManager
from QT4FormWidgets.StringFormWidget import StringFormWidget
from typing import Set, Tuple

class FaceSelectFormWidget(StringFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _FaceSelectFormWidget__adoptFacesCB(self): ...
    def _FaceSelectFormWidget__adoptMenuAboutToShow(self, menu): ...
    def _buildControlWidget(self, layout): ...
    def getMeshLocation(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class InteractiveIconTabBar(PyQt5.QtWidgets.QTabBar):
    BIG_ICON_SIZE: ClassVar[int] = ...
    tabIconClicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    tabIconEnterEvent: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    tabIconLeaveEvent: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def getIconIndex(self, pos): ...
    def getIconRect(self, index): ...
    def getMouseOverIndex(self): ...
    def mouseMoveEvent(self, ev): ...
    def mousePressEvent(self, ev): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyUtilModule.ChildProcess as ChildProcess
import ConfigurationAPI_cmodule as Configuration
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from typing import ClassVar, Set, Tuple

class FlipbookDialog(PyQt5.QtWidgets.QDialog):
    _dialogList: ClassVar[list] = ...
    def __init__(self, flipbookArguments, *args) -> None: ...
    def _FlipbookDialog__cancelRender(self): ...
    def _FlipbookDialog__idle_callback(self, eventType, eventID, **args): ...
    def _FlipbookDialog__render_flipbook(self): ...
    def _FlipbookDialog__viewerHandler_checkForFirstFrame(self): ...
    def _FlipbookDialog__viewerHandler_connectToItview(self): ...
    def _FlipbookDialog__viewerHandler_loadRemainingSequence(self): ...
    def closeEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import Manifest as Manifest, Util as Util
from QT4GLLayerStack.CheckerboardLayer import CheckerboardLayer as CheckerboardLayer
from QT4GLLayerStack.ClearLayer import ClearLayer as ClearLayer
from QT4GLLayerStack.EdgeScrollingLayer import EdgeScrollingLayer as EdgeScrollingLayer
from QT4GLLayerStack.EventEaterLayer import EventEaterLayer as EventEaterLayer
from QT4GLLayerStack.FrameAllLayer import FrameAllLayer as FrameAllLayer
from QT4GLLayerStack.LayerStack import Layer as Layer, LayerStack as LayerStack
from QT4GLLayerStack.PanInteractionLayer import PanInteractionLayer as PanInteractionLayer
from QT4GLLayerStack.RectangleLayer import RectangleLayer as RectangleLayer
from QT4GLLayerStack.ZoomAnimationLayer import ZoomAnimationLayer as ZoomAnimationLayer
from QT4GLLayerStack.ZoomInteractionLayer import ZoomInteractionLayer as ZoomInteractionLayer
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4FormWidgets.GroupFormWidget import GroupFormWidget
from QT4FormWidgets.MultiFormWidget import MultiFormWidget
from typing import Set, Tuple

class PageGroupBoxWidget(GroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _buildTopAreaLayout(self, layout): ...
    def _popdownCreated(self, popdown): ...

class PageGroupWidget(MultiFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _buildControlWidget(self, controlLayout): ...
    def _buildLabel(self, labelText, pos: int = ...): ...
    def _buildTopAreaLayout(self, layout): ...
    def _popdownCreated(self, popdown): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import GeoAPI as GeoAPI
import NodegraphAPI as NodegraphAPI
import PyFnAttribute
import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import UI4.FormMaster
import UI4.FormMaster.GenericAssignParameterPolicy_geolib3
from typing import ClassVar, Set, Tuple

class PIP(tuple):
    _field_defaults: ClassVar[dict] = ...
    _fields: ClassVar[tuple] = ...
    _fields_defaults: ClassVar[dict] = ...
    def __init__(self, _cls, nodeName, parameterName, page, label, name, hintsHash, terminalNodeHash) -> None: ...
    def _asdict(self): ...
    @classmethod
    def _make(cls, iterable): ...
    def _replace(self, _self, **kwds): ...
    def __getnewargs__(self): ...
    @property
    def hintsHash(self): ...
    @property
    def label(self): ...
    @property
    def name(self): ...
    @property
    def nodeName(self): ...
    @property
    def page(self): ...
    @property
    def parameterName(self): ...
    @property
    def terminalNodeHash(self): ...

class PublicInterfaceParameters(PyQt5.QtWidgets.QWidget):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, publicInterfacePolicy: UI4.FormMaster.GenericAssignGroupParameterPolicy) -> None: ...
    def _PublicInterfaceParameters__clearLayout(self, layout: PyQt5.QtWidgets.QLayout): ...
    def _PublicInterfaceParameters__createNodeParameterGroupPolicy(self, pagePolicyCache, publicInterfaceParameterHints, containerInterfaceHints): ...
    def _PublicInterfaceParameters__createPagePolicy(self, page: str, pagePolicyCache: dict, containerInterfaceHints: dict, ancestorPageNames: str = ...) -> QT4FormWidgets.PythonGroupPolicy: ...
    def _PublicInterfaceParameters__handleAttrSourceError(self, layout: PyQt5.QtWidgets.Qlayout, errorMessageAttr: PyFnAttribute.GroupAttribute): ...
    def _PublicInterfaceParameters__handleAttrSourceErrorFallback(self, layout, errorMessageAttr): ...
    def _PublicInterfaceParameters__on_parameterAttrSource_update(self): ...
    def _PublicInterfaceParameters__on_publicInterfaceAttrSource_update(self): ...
    def _PublicInterfaceParameters__updateAttributeSourceConnections(self, connect: bool = ...): ...
    def _PublicInterfaceParameters__updateStalePolicies(self, policies): ...
    def _freeze(self): ...
    def _isFrozen(self) -> bool: ...
    def _thaw(self): ...
    def getAttrSource(self) -> UI4.FormMaster.GenericAssignParameterPolicy_geolib3.ClientIncomingValueSource: ...
    def getAttrSourceErrorHandlers(self): ...
    def getPublicInterfacePolicy(self) -> UI4.FormMaster.GenericAssignGroupParameterPolicy: ...
    def hideEvent(self, event: PyQt5.QtGui.QHideEvent): ...
    def registerAttrSourceErrorHandler(self, attrSourceErrorHandler: None, index: int = ...) -> bool: ...
    def setPublicInterfacePolicy(self, publicInterfacePolicy: UI4.FormMaster.GenericAssignGroupParameterPolicy): ...
    def showEvent(self, event: PyQt5.QtGui.QShowEvent): ...
    def startListening(self): ...
    def stopListening(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import LiveRenderPortOpObserver
import Nodes3DAPI.Node3DEventTypes as Node3DEventTypes
import Nodes3DAPI.Node3D_geolib3 as Node3D_geolib3
import NodegraphAPI
import PyUtilModule.RenderManager.NodegraphUtils as NodegraphUtils
import Nodes3DAPI as Nodes3DAPI
import PyFnAttribute as PyFnAttribute
import PyFnGeolib as PyFnGeolib
import PyFnGeolibServices as PyFnGeolibServices
import PyUtilModule.RenderManager.RenderGlobals as RenderGlobals
import PyUtilModule.RenderManager as RenderManager
import RenderSettingsExtractor
import PyUtilModule.RenderingCommon as RenderingCommon
import PyUtilModule.RenderManager.ScenegraphUtils as ScenegraphUtils
import Utils as Utils
import abc
from Nodes3DAPI.OpCacheManager import OpCacheManager as OpCacheManager
from PyUtilModule.WorkingSet import WorkingSet as WorkingSet
from PyUtilModule.WorkingSetManager import WorkingSetManager as WorkingSetManager
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class AOVOpChain(_OpChain):
    def __init__(self, mainSequenceID: int) -> None: ...
    def _createOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, rootOp: PyFnGeolib.GeolibRuntimeOp) -> PyFnGeolib.GeolibRuntimeOp: ...

class CameraOverrideOpChain(_OpChain):
    def _createOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, rootOp: PyFnGeolib.GeolibRuntimeOp, renderCameraPath: str) -> PyFnGeolib.GeolibRuntimeOp: ...
    def applyOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, inputOp: PyFnGeolib.GeolibRuntimeOp, renderCameraType: int, renderCameraPath: str) -> PyFnGeolib.GeolibRuntimeOp: ...

class ImplicitResolversOpChain(_OpChain):
    def _createOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, rootOp: PyFnGeolib.GeolibRuntimeOp, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState) -> PyFnGeolib.GeolibRuntimeOp: ...

class IsolateOpChain(_OpArgsOpChain):
    def __init__(self) -> None: ...
    def _createOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, rootOp: PyFnGeolib.GeolibRuntimeOp, opArgs: PyFnAttribute.GroupAttribute) -> PyFnGeolib.GeolibRuntimeOp: ...
    def applyOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, inputOp: PyFnGeolib.GeolibRuntimeOp, cameraName: str) -> PyFnGeolib.GeolibRuntimeOp: ...

class LiveAttributeQueue:
    _kAttrEditorPattern: ClassVar[str] = ...
    _kAttrPathPattern: ClassVar[str] = ...
    _kAttrRootPattern: ClassVar[str] = ...
    _kLocationPathPattern: ClassVar[str] = ...
    def __init__(self) -> None: ...
    def flush(self, txn: LiveRenderPortOpObserver._TransactionProxy): ...
    def insert(self, locationPath: str, attrPath: str, attrValue: str, attrEditor: PyFnAttribute.GroupAttribute | None): ...
    def setOp(self, op: PyFnGeolib.GeolibRuntimeOp): ...

class LiveRenderOpChain:
    _opCacheManager: ClassVar[OpCacheManager] = ...
    def __init__(self, renderUUID: str, mainSequenceID: int, renderSettingsExtractor: RenderSettingsExtractor, initialImplicitResolversOpChain: ImplicitResolversOpChain, initialDefaultRenderSettingsOpChain: RenderSettingsDefaultsOpChain, implicitResolversOpChain: ImplicitResolversOpChain, defaultRenderSettingsOpChain: RenderSettingsDefaultsOpChain, isolateOpChain: IsolateOpChain, renderWorkingSetOpChain: RenderWorkingSetOpChain, renderSettingsOpChain: RenderSettingsOpChain, renderOutputsOpChain: RenderOutputsOpChain, virtualCameraOpChain: VirtualCameraOpChain, cameraOverrideOpChain: CameraOverrideOpChain, aovOpChain: AOVOpChain, roiOpChain: ROIOpChain, renderInfoPluginOpChain: RenderInfoPluginOpChain, liveRenderUpdatesOpChain: LiveRenderUpdatesOpChain) -> None: ...
    @classmethod
    def _getCachedOp(cls, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, visitedState, txn): ...
    def getOp(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, visitedState: set, txnProxy: LiveRenderPortOpObserver._TransactionProxy) -> PyFnGeolib.GeolibRuntimeOp: ...

class LiveRenderUpdatesOpChain(_OpArgsOpChain):
    def _createOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, rootOp: PyFnGeolib.GeolibRuntimeOp, workingSetOpArgs: PyFnAttribute.GroupAttribute) -> PyFnGeolib.GeolibRuntimeOp: ...
    def applyOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, inputOp: PyFnGeolib.GeolibRuntimeOp) -> PyFnGeolib.GeolibRuntimeOp: ...

class ROIOpChain(_OpChain):
    def __init__(self) -> None: ...
    def _checkAndUpdateDirtyState(self, roi) -> bool: ...
    def _createOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, rootOp: PyFnGeolib.GeolibRuntimeOp, roi) -> PyFnGeolib.GeolibRuntimeOp: ...
    def applyOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, inputOp: PyFnGeolib.GeolibRuntimeOp) -> PyFnGeolib.GeolibRuntimeOp: ...

class RenderInfoPluginOpChain(_OpChain):
    def __init__(self, liveAttributeQueue) -> None: ...
    @staticmethod
    def _RenderInfoPluginOpChain__createOp(txnProxy, opType, opArgs): ...
    def _checkAndUpdateDirtyState(self, graphState: NodegraphAPI.GraphState, renderer: str) -> bool: ...
    def _createOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, rootOp: PyFnGeolib.GeolibRuntimeOp, graphState: NodegraphAPI.GraphState, renderer: str) -> PyFnGeolib.GeolibRuntimeOp: ...

class RenderOutputsOpChain(_OpChain):
    def __init__(self) -> None: ...
    def _checkAndUpdateDirtyState(self, renderOutputs: list[str]) -> bool: ...
    def _createOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, rootOp: PyFnGeolib.GeolibRuntimeOp, renderOutputs: list[str]) -> PyFnGeolib.GeolibRuntimeOp: ...

class RenderSettingsDefaultsOpChain(_OpChain):
    def __init__(self) -> None: ...
    def _checkAndUpdateDirtyState(self, opSystemArgs: PyFnAttribute.GroupAttribute) -> bool: ...
    def _createOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, rootOp: PyFnGeolib.GeolibRuntimeOp, opSystemArgs: PyFnAttribute.GroupAttribute) -> PyFnGeolib.GeolibRuntimeOp: ...

class RenderSettingsExtractor:
    class Settings(tuple):
        _field_defaults: ClassVar[dict] = ...
        _fields: ClassVar[tuple] = ...
        _fields_defaults: ClassVar[dict] = ...
        def __init__(self, _cls, renderSettingsAttr, renderer, renderCameraPath, renderCameraType, interactiveOutputs) -> None: ...
        def _asdict(self): ...
        @classmethod
        def _make(cls, iterable): ...
        def _replace(self, _self, **kwds): ...
        def __getnewargs__(self): ...
        @property
        def interactiveOutputs(self): ...
        @property
        def renderCameraPath(self): ...
        @property
        def renderCameraType(self): ...
        @property
        def renderSettingsAttr(self): ...
        @property
        def renderer(self): ...
    def __init__(self, runtime: PyFnGeolib.GeolibRuntime) -> None: ...
    def extract(self, txn: PyFnGeolib.GeolibRuntimeTransaction, terminalOp: PyFnGeolib.GeolibRuntimeOp) -> RenderSettingsExtractor.Settings: ...
    def getCachedRootAttrs(self): ...

class RenderSettingsOpChain(_OpChain):
    def __init__(self) -> None: ...
    def _checkAndUpdateDirtyState(self, graphState: NodegraphAPI.GraphState, renderSettings: PyFnAttribute.GroupAttribute) -> bool: ...
    def _createOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, rootOp: PyFnGeolib.GeolibRuntimeOp, graphState: NodegraphAPI.GraphState, renderSettings: PyFnAttribute.GroupAttribute) -> PyFnGeolib.GeolibRuntimeOp: ...

class RenderWorkingSetOpChain(_OpArgsOpChain):
    def _createOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, rootOp: PyFnGeolib.GeolibRuntimeOp, opArgs: PyFnAttribute.GroupAttribute) -> PyFnGeolib.GeolibRuntimeOp: ...
    def applyOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, inputOp: PyFnGeolib.GeolibRuntimeOp, cameraName: str) -> PyFnGeolib.GeolibRuntimeOp: ...

class VirtualCameraOpChain(_OpChain):
    def _createOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, rootOp: PyFnGeolib.GeolibRuntimeOp) -> PyFnGeolib.GeolibRuntimeOp: ...
    def applyOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, inputOp: PyFnGeolib.GeolibRuntimeOp, renderCameraPath: str) -> PyFnGeolib.GeolibRuntimeOp: ...

class _OpArgsOpChain(_OpChain):
    def __init__(self) -> None: ...
    def _checkAndUpdateDirtyState(self, opArgs: PyFnAttribute.GroupAttribute) -> bool: ...

class _OpChain(_OpPool):
    __metaclass__: ClassVar[type[abc.ABCMeta]] = ...
    def __init__(self, rootOp: Incomplete | None = ..., terminalOp: Incomplete | None = ...) -> None: ...
    def _OpChain__reset(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, *args, **kwargs): ...
    @staticmethod
    def _applyOp(txnProxy: LiveRenderPortOpObserver._TransactionProxy, inputOp: PyFnGeolib.GeolibRuntimeOp, opType: str, opArgs: PyFnAttribute.GroupAttribute = ...) -> PyFnGeolib.GeolibRuntimeOp: ...
    def _checkAndUpdateDirtyState(self, args: tuple, kwargs: dict) -> bool: ...
    def _createOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, rootOp: PyFnGeolib.GeolibRuntimeOp, *args, **kwargs) -> PyFnGeolib.GeolibRuntimeOp: ...
    def applyOpChain(self, txnProxy: LiveRenderPortOpObserver._TransactionProxy, inputOp: PyFnGeolib.GeolibRuntimeOp, *args, **kwargs) -> PyFnGeolib.GeolibRuntimeOp: ...

class _OpPool:
    def __init__(self) -> None: ...
    def _release(self): ...

def _pairwise(iterable): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.HintUtils as HintUtils
import QT4FormWidgets.InputWidgets as InputWidgets
import QT4FormWidgets.PaintingUtils as PaintingUtils
import PyQt5.QtCore
import QT4FormWidgets.InputWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import QT4FormWidgets.ValueAdjustment as ValueAdjustment
from QT4FormWidgets.BaseValueFormWidget import BaseValueFormWidget as BaseValueFormWidget
from QT4FormWidgets.MultiStateBadge import MultiStateBadge as MultiStateBadge, ToggleStateBadge as ToggleStateBadge, ToggleValuePolicyState as ToggleValuePolicyState
from typing import ClassVar, Set, Tuple

class IncDecLineEdit(QT4FormWidgets.InputWidgets.InputLineEdit):
    singleDigitScrollingEnabled: ClassVar[bool] = ...
    superEnter: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def keyPressEvent(self, event): ...

class NumberFormWidget(BaseValueFormWidget):
    SLOP: ClassVar[int] = ...
    def __init__(self, parent, policy, factory) -> None: ...
    def _NumberFormWidget__calcSliderValue(self, pos): ...
    def _NumberFormWidget__control_decrement_CB(self, modifiers): ...
    def _NumberFormWidget__control_increment_CB(self, modifiers): ...
    def _NumberFormWidget__control_superEnter_CB(self): ...
    def _NumberFormWidget__on_control_lostFocus(self): ...
    def _NumberFormWidget__sensitivityMenuCallback(self, action): ...
    def _NumberFormWidget__slider_toggleComponent_CB(self): ...
    def _NumberFormWidget__slider_valueChanged_CB(self, value, final): ...
    def _addExportMenuActions(self, menu): ...
    def _addExtraMenuAction(self, menu): ...
    def _addImportMenuActions(self, menu): ...
    def _buildControlWidget(self, layout): ...
    def _checkControlWidget(self): ...
    def _lockChanged(self, state): ...
    def _popupMenuCreated(self, menu): ...
    def _resetScrubbing(self): ...
    def _updateControlWidget(self): ...
    def getLabelSensitivity(self): ...
    def getMaxVal(self): ...
    def labelSliderBegin(self, pos, modifiers): ...
    def labelSliderDrag(self, pos, modifiers): ...
    def labelSliderEnd(self, pos, modifiers): ...
    def paintEvent(self, event): ...
    def setLabelSensitivity(self, sensitivity): ...
    def setMaxVal(self, max): ...
    @classmethod
    def setSingleDigitScrolling(cls, value: bool): ...
    def supportsStickyScrub(self) -> bool: ...

def CreateSensitivityMenu(menu, policy, isInt, sensitivity): ...
def FormatNumber(value: Tuple[float, int | int], isInt: bool = ..., numDigits: int = ...) -> str: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import PyFnAttribute as FnAttribute
import UI4.Widgets.MonitorLayer.Utils as MonitorLayerUtils
import PyOpenColorIO as OCIO
import PyFnAttribute
import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.RenderManager as RenderManager
import UI4 as UI4
import Utils as Utils
import QT4Widgets.WidgetUtils as WidgetUtils
import typing
from Callbacks.Callbacks import Callbacks as Callbacks
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

MONITOR_LAYER_DEFAULT: bool

class AOVSelector(PyQt5.QtCore.QObject):
    aovsChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    currentAOVChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    currentAOVIndexChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    selectedAOVChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    useSelectedAOVChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    aovs: Incomplete
    selectedAOV: Incomplete
    useSelectedAOV: Incomplete
    def __init__(self) -> None: ...
    def _AOVSelector__shiftSelectedAOV(self, shift): ...
    def _AOVSelector__updateCurrentAOV(self): ...
    def selectNextAOV(self): ...
    def selectPreviousAOV(self): ...
    @property
    def currentAOV(self): ...
    @property
    def currentAOVIndex(self): ...
    @property
    def selectedAOVIndex(self): ...

class MonitorLayerDropdownButton(PyQt5.QtWidgets.QPushButton):
    def __init__(self, text, toolTip, defaultPixmapPath, activePixmapPath, height, parent: Incomplete | None = ...) -> None: ...
    def _MonitorLayerDropdownButton__sizeHint(self, size): ...
    def enterEvent(self, ev): ...
    def leaveEvent(self, ev): ...
    def minimumSizeHint(self): ...
    def paintEvent(self, ev): ...
    def sizeHint(self): ...

class ToggleButton(_ToggleButton):
    MONITOR_LAYER_PIXMAPS: ClassVar[tuple] = ...
    def __init__(self, parent, size) -> None: ...

class ToolBar(PyQt5.QtWidgets.QFrame):
    class AovToolControl(tuple):
        _field_defaults: ClassVar[dict] = ...
        _fields: ClassVar[tuple] = ...
        _fields_defaults: ClassVar[dict] = ...
        def __init__(self, _cls, button, menu) -> None: ...
        def _asdict(self): ...
        @classmethod
        def _make(cls, iterable): ...
        def _replace(self, _self, **kwds): ...
        def __getnewargs__(self): ...
        @property
        def button(self): ...
        @property
        def menu(self): ...

    class ViewTransformControl(tuple):
        _field_defaults: ClassVar[dict] = ...
        _fields: ClassVar[tuple] = ...
        _fields_defaults: ClassVar[dict] = ...
        def __init__(self, _cls, toggle, button, menu) -> None: ...
        def _asdict(self): ...
        @classmethod
        def _make(cls, iterable): ...
        def _replace(self, _self, **kwds): ...
        def __getnewargs__(self): ...
        @property
        def button(self): ...
        @property
        def menu(self): ...
        @property
        def toggle(self): ...
    AOV_TOOLTIP_TEMPLATE: ClassVar[str] = ...
    COPY_TO_CEL_PIXMAPS: ClassVar[tuple] = ...
    DOWN_ARROW_PIXMAPS: ClassVar[tuple] = ...
    ID_BUFFER_PIXMAPS: ClassVar[tuple] = ...
    MAX_TEXT_LENGTH: ClassVar[int] = ...
    NO_AOVS_TEXT: ClassVar[str] = ...
    NO_AOVS_TOOLTIP: ClassVar[str] = ...
    ROI_PIXMAPS: ClassVar[tuple] = ...
    ROI_RESET_HANDLE_PIXMAPS: ClassVar[tuple] = ...
    ROI_SHOW_HANDLE_PIXMAPS: ClassVar[tuple] = ...
    SELECT_AND_EXPAND_PIXMAPS: ClassVar[tuple] = ...
    SWITCH_VIEW_PIXMAPS: ClassVar[tuple] = ...
    def __init__(self, tab, buttonSize) -> None: ...
    def _ToolBar__buildIdBufferToolTip(self) -> str: ...
    def _ToolBar__createAOVToolControl(self, buttonSize): ...
    def _ToolBar__createIdBufferToggle(self, buttonSize): ...
    def _ToolBar__createROIWidgets(self, buttonSize: int): ...
    def _ToolBar__createSwitchViewMenu(self): ...
    def _ToolBar__createToggle(self, name, defaultPixmap, activePixmap, buttonSize): ...
    def _ToolBar__createViewTransformControl(self, buttonSize): ...
    def _ToolBar__onAOVMenuOpened(self, checked): ...
    def _ToolBar__onAOVSelected(self, action): ...
    def _ToolBar__onAOVsChanged(self): ...
    def _ToolBar__onCurrentAOVChanged(self): ...
    def _ToolBar__onCurrentAOVIndexChanged(self): ...
    def _ToolBar__onIdBufferToggled(self, checked): ...
    def _ToolBar__onSelectedAOVChanged(self): ...
    def _ToolBar__onUseSelectedAOVChanged(self): ...
    def _ToolBar__onViewMenuOpened(self, checked): ...
    def _ToolBar__onViewSelected(self, action): ...
    def _ToolBar__onViewToggled(self, checked): ...
    def _ToolBar__on_catalog_clientSlotUpdate(self, eventType, eventID): ...
    def _ToolBar__on_catalog_externalBufferLoaded(self, eventType, eventID, item, **kwargs): ...
    def _ToolBar__on_catalog_itemDelete(self, eventType, eventID, item): ...
    def _ToolBar__on_catalog_itemPropertyUpdate(self, args): ...
    def _ToolBar__on_catalog_rebuild(self, eventType, eventID): ...
    def _ToolBar__on_pref_changed(self, eventType: str | None, eventID: typing.Hashable, prefKey: str, prefValue: object): ...
    def _ToolBar__on_renderManager_roiChanged(self, eventType, eventID): ...
    def _ToolBar__on_roiMenu_aboutToShow(self): ...
    def _ToolBar__on_roiShowHandleAction_triggered(self, checked: bool): ...
    def _ToolBar__populateAOVMenuActions(self, menu): ...
    def _ToolBar__populateAOVToolTipWithShortcuts(self): ...
    def _ToolBar__setMonitorAOVLayerIndex(self, index): ...
    @staticmethod
    def _ToolBar__setStyleSheetProperty(widget, propertyName, propertyValue): ...
    def _ToolBar__updateAOVButton(self): ...
    def _ToolBar__updateAOVsFromCatalog(self): ...
    def allowIDBuffer(self, allow): ...
    def defaultAOV(self): ...
    def getCurrentAOV(self): ...
    def isIDBufferEnabled(self) -> bool: ...
    def nextAOV(self): ...
    def onResetROICallback(self, attr: PyFnAttribute.Attribute): ...
    def onSetROICallback(self, attr: PyFnAttribute.GroupAttribute): ...
    def previousAOV(self): ...
    def setIDBufferEnabled(self, enabled: bool): ...
    def toggleSelectedAOV(self): ...
    def toggleViewTransform(self): ...
    def updateROI(self, enabled: Incomplete | None = ...): ...
    @property
    def _ToolBar__viewerDelegate(self): ...

class _ToggleButton(ToolbarButton):
    stateChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, toolTip, parent, buttonSize, normalPixmap, onPixmap, rolloverPixmap: Incomplete | None = ..., onRolloverPixmap: Incomplete | None = ..., defaultValue: bool = ...) -> None: ...
    def _ToggleButton__clicked(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import NodegraphAPI as NodegraphAPI
import PyQt5.QtGui
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
import UI4.Widgets as Widgets
from QT4FormWidgets.FormWidget import FormWidget
from _typeshed import Incomplete
from typing import Set, Tuple

class ShadingNodeSubnetInterfaceOrderFormWidget(FormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _ShadingNodeSubnetInterfaceOrderFormWidget__aboutToDragCallback(self, items, dragObject): ...
    def _ShadingNodeSubnetInterfaceOrderFormWidget__dragMoveEventCallback(self, event, parent, index, callbackRecord): ...
    def _ShadingNodeSubnetInterfaceOrderFormWidget__dropEventCallback(self, event, parent, index): ...
    def _ShadingNodeSubnetInterfaceOrderFormWidget__findItemIndex(self, item): ...
    def _ShadingNodeSubnetInterfaceOrderFormWidget__getParameterDrop(self, event): ...
    def _ShadingNodeSubnetInterfaceOrderFormWidget__getSliceCount(self, item, count: Incomplete | None = ...): ...
    def _ShadingNodeSubnetInterfaceOrderFormWidget__jumpToSource(self): ...
    def _ShadingNodeSubnetInterfaceOrderFormWidget__listMousePressEvent(self, event): ...
    def _ShadingNodeSubnetInterfaceOrderFormWidget__menuAboutToShow(self, menu, selectedItems: Incomplete | None = ...): ...
    def _ShadingNodeSubnetInterfaceOrderFormWidget__treeContextMenuCallback(self, event: PyQt5.QtGui.QContextMenuEvent): ...
    def _ShadingNodeSubnetInterfaceOrderFormWidget__updateTree(self): ...
    def _buildLabel(self, labelText, pos: int = ...): ...
    def valueChangedEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtCore as QtCore
import typing
from typing import Set, Tuple

MIME_TYPE_COLLECTIONS: str
MIME_TYPE_LOCATIONPATHS: str
MIME_TYPE_NODEREFS: str
MIME_TYPE_NODES: str
MIME_TYPE_PYTHON: str

def GetCollections(mimeDataOrDropEvent: PyQt5.QtCore.QMimeData | PyQt5.QtGui.QDropEvent) -> typing.Optional[list[d]]: ...
def GetLocationPaths(mimeDataOrDropEvent: PyQt5.QtCore.QMimeData | PyQt5.QtGui.QDropEvent, excludePolicyXML: bool = ...) -> typing.Optional[list[s]]: ...
def GetNodes(mimeDataOrDropEvent: PyQt5.QtCore.QMimeData | PyQt5.QtGui.QDropEvent, nodesCreatingSceneGraphLocationsOnly: bool = ...) -> list | None: ...
def SetCollections(mimeData: PyQt5.QtCore.QMimeData, collectionMaps: list[dict]): ...
def SetLocationPaths(mimeData: PyQt5.QtCore.QMimeData, locationPaths): ...
def SetNodes(mimeDataOrDragObject: PyQt5.QtCore.QMimeData | PyQt5.QtGui.QDrag, nodeNamesOrNodes: str | NodegraphAPI.Node | list[str | NodegraphAPI.Node]): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import Nodes3DAPI as Nodes3DAPI
import PyFnGeolibProducers
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtWidgets as QtWidgets
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
from QT4FormWidgets.GroupFormWidget import GroupFormWidget
from typing import Set, Tuple

class FacesetTexturesDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, producer: PyFnGeolibProducers.GeometryProducer) -> None: ...
    def _FacesetTexturesDialog__viewSelected(self): ...

class TexturesGroupFormWidget(GroupFormWidget):
    def _TexturesGroupFormWidget__facesetInterpret(self): ...
    def _TexturesGroupFormWidget__update(self, eventType, scenegraphID, isRenderProducer, **kwargs): ...
    def _buildControlWidget(self, layout): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import Utils as Utils
from NodegraphAPI.NodegraphGlobals import GetRootNode as GetRootNode
from NodegraphAPI_cmodule import GroupNode as GroupNode
from typing import Set, Tuple

saveflags: int
useFlags: bool

def connectFromGroupContents(currentOutPort, targetGroupNode): ...
def connectToGroupContents(currentOutPort, targetGroupNode): ...
def connectToPortOutsideOfCurrentGroup(producerPort, consumerPort): ...
def findPathBetween(sourcePort, destPort): ...
def getNodeDepth(node: NodegraphAPI.Node): ...
def getNodeListToRoot(node: NodegraphAPI.Node): ...
def getUniqueName(name, checkcallback): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import QT4FormWidgets.WidgetFactory as WidgetFactory
from QT4FormWidgets.PythonValuePolicy import PythonDictValuePolicy as PythonDictValuePolicy
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class FormDialog(PyQt5.QtWidgets.QDialog):
    _DefaultRootHints: ClassVar[dict] = ...
    def __init__(self, dataSource, parent: Incomplete | None = ..., factory: Incomplete | None = ..., title: Incomplete | None = ..., okLabel: str = ..., cancelLabel: str = ...) -> None: ...
    def getValuePolicy(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import BaseFarmPlugin as BaseFarmPlugin
import FarmAPI.FarmPluginManager
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class BaseFarmPlugin:
    class InstallationMetadata:
        def __init__(self, katanaRoot: str, renderPluginDsoPaths, renderbootCommand: Incomplete | None = ...) -> None: ...
    def copyRenderFiles(self, filenames: list[str], renderContextName: str): ...
    def createTemporaryDirectory(self, renderContextName: str) -> str: ...
    def getEnvironmentForJob(self, renderContextName: str): ...
    def getJobState(self, jobId: str) -> str: ...
    def getJobs(self, filters: list) -> list: ...
    def getRemoteInstallationMetadata(self) -> BaseFarmPlugin.InstallationMetadata: ...
    def getRenderLogFilename(self, jobId: str) -> str | None: ...
    def startJob(self, jobId: str): ...
    def stopJob(self, jobId: str): ...
    def submitJob(self, jobRequest: FarmAPI.FarmPluginManager.JobRequest) -> str: ...

class FarmPluginException(Exception): ...

class Job:
    class State:
        kAllStates: ClassVar[tuple] = ...
        kCancelled: ClassVar[str] = ...
        kCompleted: ClassVar[str] = ...
        kFailed: ClassVar[str] = ...
        kRunning: ClassVar[str] = ...
        kWaiting: ClassVar[str] = ...
    def __init__(self, jobId: str, name: str, startTime: int, endTime: int, state: str, renderLogFilename: str) -> None: ...

class JobNotFoundException(FarmPluginException):
    def __init__(self, jobId: str, contextMessage: str) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from QT4FormWidgets.GroupFormWidget import GroupFormWidget
from _typeshed import Incomplete
from typing import Set, Tuple

class PresetsGroupFormWidget(GroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _PresetsGroupFormWidget__comparePresetValuesType(self, values1, values2): ...
    def _PresetsGroupFormWidget__initParser(self): ...
    def _PresetsGroupFormWidget__parsePresetValues(self, valuesStr: str) -> list | None: ...
    def _PresetsGroupFormWidget__parsePresets(self, presetsString: str) -> list: ...
    def _PresetsGroupFormWidget__presetComboBox_CB(self, requestedPresetName): ...
    def _PresetsGroupFormWidget__syncPresetComboBox(self, event: Incomplete | None = ...): ...
    def _buildControlWidget(self, layout): ...
    def _freeze(self): ...
    def _thaw(self): ...
